<template>
    <div class="text-center">
      <div class="text-body-2 font-weight mb-n1">Welcome to</div>
      <h1 class="text-h2 font-weight-bold">Archive Query Log</h1>
      <div class="text-body-2 font-weight-light">
        The Archive Query Log monitoring interface.
      </div>
  
      <div class="py-4"></div>
  
      <v-btn
        text
        href="https://github.com/webis-de/archive-query-log"
        class="button-margin"
        >GitHub</v-btn
      >
      <v-btn
        text
        href="https://webis.de/publications.html?q=archive#reimer_2023"
        class="button-margin"
        >Paper</v-btn
      >
      <v-btn text href="https://webis.de/">Webis</v-btn>
    </div>
  </template>
  
  <style>
  .button-margin {
    margin-right: 100px;
  }
  </style>
  