# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_ebay_se_xing_mei_jia_wei_vxin_dun35358_1544323503():
    verify_serp_parsing(
        "https://web.archive.org/web/20181209024503id_/https://www.ebay.ca/sch/i.html?_nkw=%E8%89%B2%E6%80%A7%E5%A6%B9%E3%80%90%E5%8A%A0%E5%BE%AEv%E4%BF%A1%3Adun35358%E3%80%91%E2%8A%99",
        "ebay",
    )


def test_parse_query_ebay_shan_dong_11xuan_5_360cai_piao_wei_xin_weiwei776699_1538125942():
    verify_serp_parsing(
        "https://web.archive.org/web/20180928091222id_/https://www.ebay.ph/sch/i.html?_nkw=%E5%B1%B1%E4%B8%9C11%E9%80%895+360%E5%BD%A9%E7%A5%A8%2B%E3%80%96%E5%BE%AE%E4%BF%A1%3Aweiwei776699%E3%80%97%E2%94%A0",
        "ebay",
    )


def test_parse_query_ebay_smartphones_1334931269():
    verify_serp_parsing(
        "https://web.archive.org/web/20120420141429id_/http://www.ebay.de/sch/i.html?_nkw=Smartphones&_sacat=132286&rt=nc",
        "ebay",
    )


def test_parse_query_ebay_srch_str_1641320481():
    verify_serp_parsing(
        "https://web.archive.org/web/20220104182121id_/https://www.ebay.com.sg/sch/i.html?_nkw={srch_str}&ssPageName=GSTL",
        "ebay",
    )


def test_parse_query_ebay_liu_he_cai_gua_pai_wan_zheng_ban_wei_vxin_weiwei776699_1565563054():
    verify_serp_parsing(
        "https://web.archive.org/web/20190811223734id_/https://www.ebay.com.sg/sch/i.html?_nkw=%e5%85%ad%e5%90%88%e5%bd%a9%e6%8c%82%e7%89%8c%e5%ae%8c%e6%95%b4%e6%9d%bf%c2%b1%e3%80%90%e5%be%aev%e4%bf%a1weiwei776699%e3%80%91%e2%97%86",
        "ebay",
    )


def test_parse_query_ebay_1_4_1566151598():
    verify_serp_parsing(
        "https://web.archive.org/web/20190818180638id_/https://www.ebay.com/sch/i.html?rt=nc&_fsrp=1&_nkw=1+%3A+4+&_sacat=14964&Connector%2520A=RCA%252FPhono%2520Male",
        "ebay",
    )


def test_parse_query_ebay_hu_bei_kuai_san_zhong_jiang_zhu_shou_jia_wei_vxin_weiwei776699_1548361753():
    verify_serp_parsing(
        "https://web.archive.org/web/20190124202913id_/https://www.ebay.ph/sch/i.html?_nkw=%e6%b9%96%e5%8c%97%e5%bf%ab%e4%b8%89%e4%b8%ad%e5%a5%96%e5%8a%a9%e6%89%8b%e5%8a%a0%e3%80%8e%e5%be%aev%e4%bf%a1weiwei776699%e3%80%8f%e2%88%9a",
        "ebay",
    )


def test_parse_query_ebay_imaginext_batman_motorcycle_1597143554():
    verify_serp_parsing(
        "https://web.archive.org/web/20200811105914id_/https://www.ebay.com/sch/i.html?_nkw=imaginext+batman+motorcycle&rt=nc&_dcat=50305&_sacat=50305&vbn_id=7023320428&Featured%2520Refinements=Imaginext%2520Figure&_fsrp=1",
        "ebay",
    )


def test_parse_query_ebay_victoria_s_secret_1559541146():
    verify_serp_parsing(
        "https://web.archive.org/web/20190603055226id_/https://www.ebay.co.uk/sch/i.html?_nkw=Victoria%27s+Secret&rt=nc&_dcat=11514&_sacat=-1&cc_bn_id=21837960&_aspectname=aspect-Features&_fsrp=1",
        "ebay",
    )


def test_parse_query_ebay_liu_he_cai_2o2526_wei_xin_weiwei776699_1562672411():
    verify_serp_parsing(
        "https://web.archive.org/web/20190709114011id_/https://www.ebay.nl/sch/i.html?_nkw=%e5%85%ad%e5%90%88%e5%bd%a92o2526%2b%e3%80%8e%e5%be%ae%e4%bf%a1%3aweiwei776699%e3%80%8f%e2%96%b3",
        "ebay",
    )
