# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_imgur_search_term_string_1565643838():
    verify_serp_parsing(
        "https://web.archive.org/web/20190812210358id_/https://imgur.com/search?q={search_term_string}",
        "imgur",
    )


def test_parse_query_imgur_search_term_string_1547858079():
    verify_serp_parsing(
        "https://web.archive.org/web/20190119003439id_/https://imgur.com/search?q={search_term_string}",
        "imgur",
    )
