# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_qq_danil_kozlovsky_1360453772():
    verify_serp_parsing(
        "https://web.archive.org/web/20130209234932id_/http://v.qq.com/search.html?pagetype=3&stag=word.tag&ms_key=danil%20kozlovsky",
        "qq",
    )


def test_parse_query_qq_feng_mi_lian_1380895166():
    verify_serp_parsing(
        "https://web.archive.org/web/20131004135926id_/http://v.qq.com/search.html?pagetype=3&stag=word.tag&ms_key=%E5%B3%B0%E5%B9%82%E6%81%8B",
        "qq",
    )


def test_parse_query_qq_ji_lin_yan_ji_1360789033():
    verify_serp_parsing(
        "https://web.archive.org/web/20130213205713id_/http://v.qq.com:80/search.html?pagetype=3&ms_key=%E5%90%89%E6%9E%97%E5%BB%B6%E5%90%89",
        "qq",
    )


def test_parse_query_qq_zhong_nian_wei_ji_1408289827():
    verify_serp_parsing(
        "https://web.archive.org/web/20140817153707id_/http://v.qq.com/search.html?pagetype=3&stag=word.tag&ms_key=%E4%B8%AD%E5%B9%B4%E5%8D%B1%E6%9C%BA",
        "qq",
    )


def test_parse_query_qq_jie_ke_luo_de_wei_er_1445892389():
    verify_serp_parsing(
        "https://web.archive.org/web/20151026204629id_/http://v.qq.com/search.html?pagetype=3&stag=txt.playpage.sports&ms_key=%E6%9D%B0%E5%85%8B.%E7%BD%97%E5%BE%B7%E7%BB%B4%E5%B0%94",
        "qq",
    )


def test_parse_query_qq_lin_xi_tong_1507483207():
    verify_serp_parsing(
        "https://web.archive.org/web/20171008172007id_/http://v.qq.com/search.html?pagetype=3&stj2=tiket&ms_key=%E6%9E%97%E7%86%B9%E7%9E%B3",
        "qq",
    )


def test_parse_query_qq_shen_shan_zheng_er_lang_1405119212():
    verify_serp_parsing(
        "https://web.archive.org/web/20140711225332id_/http://v.qq.com//search.html?pagetype=3&ms_key=%E7%A5%9E%E5%B1%B1%E5%BE%81%E4%BA%8C%E9%83%8E",
        "qq",
    )


def test_parse_query_qq_james_boshier_1449178049():
    verify_serp_parsing(
        "https://web.archive.org/web/20151203212729id_/http://v.qq.com//search.html?pagetype=3&ms_key=James+Boshier",
        "qq",
    )


def test_parse_query_qq_ji_zhou_dao_ttglao_hu_ji_ping_tai_guan_wang_x_fa33n_comx_1488991663():
    verify_serp_parsing(
        "https://web.archive.org/web/20170308164743id_/http://v.qq.com/search.html?pagetype=3&stj2=search.search&stag=txt.index&ms_key=%E6%B5%8E%E5%B7%9E%E5%B2%9Bttg%E8%80%81%E8%99%8E%E6%9C%BA%E5%B9%B3%E5%8F%B0%E5%AE%98%E7%BD%91%E3%80%93FA33N.COM%E3%80%93",
        "qq",
    )


def test_parse_query_qq_hua_ze_xiang_cai_1408309927():
    verify_serp_parsing(
        "https://web.archive.org/web/20140817211207id_/http://v.qq.com//search.html?pagetype=3&ms_key=%E8%8A%B1%E6%B3%BD%E9%A6%99%E8%8F%9C",
        "qq",
    )


def test_parse_query_qq_zhang_dong_jian_1446133153():
    verify_serp_parsing(
        "https://web.archive.org/web/20151029153913id_/http://v.qq.com//search.html?pagetype=3&ms_key=%E5%BC%A0%E4%B8%9C%E5%81%A5",
        "qq",
    )


def test_parse_query_qq_jin_xiu_long_1320298924():
    verify_serp_parsing(
        "https://web.archive.org/web/20111103054204id_/http://v.qq.com/search.html?pagetype=3&ms_key=%E9%87%91%E7%A7%80%E9%BE%99",
        "qq",
    )


def test_parse_query_qq_xing_xing_di_qiu_2_1582812539():
    verify_serp_parsing(
        "https://web.archive.org/web/20200227140859id_/http://v.qq.com:80/search.html?ms_key=%E8%A1%8C%E6%98%9F%E5%9C%B0%E7%90%832",
        "qq",
    )


def test_parse_query_qq_turn_that_finger_around_1324266860():
    verify_serp_parsing(
        "https://web.archive.org/web/20111219035420id_/http://v.qq.com:80/search.html?pagetype=3&ms_key=Turn+That+Finger+Around",
        "qq",
    )


def test_parse_query_qq_statue_1536122094():
    verify_serp_parsing(
        "https://web.archive.org/web/20180905043454id_/http://v.qq.com:80/search.html?pagetype=3&stj2=search.search&stag=txt.index&ms_key=statue",
        "qq",
    )


def test_parse_query_qq_erin_1359911760():
    verify_serp_parsing(
        "https://web.archive.org/web/20130203171600id_/http://v.qq.com//search.html?pagetype=3&ms_key=Erin",
        "qq",
    )


def test_parse_query_qq_jin_cheng_wu_2_1319745059():
    verify_serp_parsing(
        "https://web.archive.org/web/20111027195059id_/http://v.qq.com/search.html?pagetype=3&ms_key=%E9%87%91%E5%9F%8E%E6%AD%A6",
        "qq",
    )


def test_parse_query_qq_tag_encode_1341871817():
    verify_serp_parsing(
        "https://web.archive.org/web/20120709221017id_/http://v.qq.com/search.html?pagetype=3&ms_key=${tag|encode}",
        "qq",
    )


def test_parse_query_qq_niamh_cusack_1319741306():
    verify_serp_parsing(
        "https://web.archive.org/web/20111027213506id_/http://v.qq.com/search.html?pagetype=3&ms_key=Niamh+Cusack",
        "qq",
    )
