# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_yahoo_diver_lg_u8180_1620023310():
    verify_serp_parsing(
        "https://web.archive.org/web/20210503062830id_/https://it.search.yahoo.com/search?p=+diver+LG+U8180&fr=yfp-t-501&ei=UTF-8&rd=r1",
        "yahoo",
    )


def test_parse_query_yahoo_civil_code_1658358754():
    verify_serp_parsing(
        "https://web.archive.org/web/20220720231234id_/https://search.yahoo.com/search?p=Civil%20Code",
        "yahoo",
    )


def test_parse_query_yahoo_world_greek_kata_periokhe_boreia_amerike_kanadas_1647085990():
    verify_serp_parsing(
        "https://web.archive.org/web/20220312115310id_/https://search.yahoo.com/search?p=World+Greek+%CE%9A%CE%B1%CF%84%CE%AC+%CE%A0%CE%B5%CF%81%CE%B9%CE%BF%CF%87%CE%AE+%CE%92%CF%8C%CF%81%CE%B5%CE%B9%CE%B1+%CE%91%CE%BC%CE%B5%CF%81%CE%B9%CE%BA%CE%AE+%CE%9A%CE%B1%CE%BD%CE%B1%CE%B4%CE%AC%CF%82&ei=UTF-8&nojs=1",
        "yahoo",
    )


def test_parse_query_yahoo_lm_1376048795():
    verify_serp_parsing(
        "https://web.archive.org/web/20130809114635id_/http://search.yahoo.com/search?p=%3Blm",
        "yahoo",
    )


def test_parse_query_yahoo_ashland_oregon_1015423512():
    verify_serp_parsing(
        "https://web.archive.org/web/20020306140512id_/http://search.yahoo.com:80/search?p=ashland+oregon+",
        "yahoo",
    )


def test_parse_query_yahoo_lawyer_career_information_970996615():
    verify_serp_parsing(
        "https://web.archive.org/web/20001008091655id_/http://search.yahoo.com:80/search?p=lawyer+career+information",
        "yahoo",
    )


def test_parse_query_yahoo_world_hebrew_hbrh_shlvm_1489427128():
    verify_serp_parsing(
        "https://web.archive.org/web/20170313174528id_/https://search.yahoo.com/search?p=World+Hebrew+%D7%97%D7%91%D7%A8%D7%94+%D7%A9%D7%9C%D7%95%D7%9D",
        "yahoo",
    )


def test_parse_query_yahoo_john_mccain_956454509():
    verify_serp_parsing(
        "https://web.archive.org/web/20000423014829id_/http://search.yahoo.com:80/search?p=John+McCain&hn=48",
        "yahoo",
    )


def test_parse_query_yahoo_bc_gov_971492707():
    verify_serp_parsing(
        "https://web.archive.org/web/20001014030507id_/http://search.yahoo.com:80/search?p=bc+gov",
        "yahoo",
    )


def test_parse_query_yahoo_region_de_coquimbo_970960857():
    verify_serp_parsing(
        "https://web.archive.org/web/20001007232057id_/http://search.yahoo.com:80/search?p=region+de+coquimbo",
        "yahoo",
    )


def test_parse_query_yahoo_learn_to_focus_1619373855():
    verify_serp_parsing(
        "https://web.archive.org/web/20210425180415id_/https://search.yahoo.com/search?p=learn+to+focus&amp;fr2=sb-top&amp;sao=1",
        "yahoo",
    )


def test_parse_query_yahoo_castle_heights_angeles_1611631735():
    verify_serp_parsing(
        "https://web.archive.org/web/20210126032855id_/http://search.yahoo.com/search?fr=sbcfp&p=%22castle+heights%22+angeles",
        "yahoo",
    )


def test_parse_query_yahoo_dunwells_army_of_friends_1617218301():
    verify_serp_parsing(
        "https://web.archive.org/web/20210331191821id_/https://search.yahoo.com/search?p=dunwells+army+of+friends&fr=iphone&.tsrc=apple&pcarrier=AT&T&pmcc=310&pmnc=410",
        "yahoo",
    )


def test_parse_query_yahoo_sam_bush_1016625678():
    verify_serp_parsing(
        "https://web.archive.org/web/20020320120118id_/http://search.yahoo.com:80/search?p=Sam+Bush",
        "yahoo",
    )


def test_parse_query_yahoo_telekwiaciarnia_pl_1436841282():
    verify_serp_parsing(
        "https://web.archive.org/web/20150714023442id_/http://nl.search.yahoo.com/search?fr=yhs-invalid&p=telekwiaciarnia.pl",
        "yahoo",
    )


def test_parse_query_yahoo_jello_gelatin_971145484():
    verify_serp_parsing(
        "https://web.archive.org/web/20001010023804id_/http://search.yahoo.com:80/search?p=jello+gelatin",
        "yahoo",
    )


def test_parse_query_yahoo_molly_shannon_1640079691():
    verify_serp_parsing(
        "https://web.archive.org/web/20211221094131id_/https://search.yahoo.com/search?p=Molly%20Shannon",
        "yahoo",
    )


def test_parse_query_yahoo_dating_sites_1647656764():
    verify_serp_parsing(
        "https://web.archive.org/web/20220319022604id_/https://search.yahoo.com/search?ei=UTF-8&p=dating+sites&fr2=p%3As%2Cv%3Asfp%2Cm%3Aovncp&fr=sfp",
        "yahoo",
    )


def test_parse_query_yahoo_metallurgi_1042532635():
    verify_serp_parsing(
        "https://web.archive.org/web/20030114082355id_/http://search.yahoo.com:80/search?p=metallurgi",
        "yahoo",
    )


def test_parse_query_yahoo_futurama_1314932107():
    verify_serp_parsing(
        "https://web.archive.org/web/20110902025507id_/http://tv.yahoo.com:80/search?cs=bz&p=Futurama&fr=tv-tts",
        "yahoo",
    )


def test_parse_query_yahoo_gabel_970409689():
    verify_serp_parsing(
        "https://web.archive.org/web/20001001141449id_/http://search.yahoo.com:80/search?p=gabel",
        "yahoo",
    )


def test_parse_query_yahoo_gina_mckee_998889511():
    verify_serp_parsing(
        "https://web.archive.org/web/20010827051831id_/http://search.yahoo.com:80/search?p=Gina+McKee",
        "yahoo",
    )


def test_parse_query_yahoo_fruitarianism_970289154():
    verify_serp_parsing(
        "https://web.archive.org/web/20000930044554id_/http://search.yahoo.com:80/search?p=fruitarianism",
        "yahoo",
    )


def test_parse_query_yahoo_gamefaq_970449707():
    verify_serp_parsing(
        "https://web.archive.org/web/20001002012147id_/http://search.yahoo.com:80/search?p=gamefaq",
        "yahoo",
    )


def test_parse_query_yahoo_glass_tools_961515348():
    verify_serp_parsing(
        "https://web.archive.org/web/20000620153548id_/http://search.yahoo.com:80/search?p=glass+tools",
        "yahoo",
    )


def test_parse_query_yahoo_bill_callahan_american_football_1636808341():
    verify_serp_parsing(
        "https://web.archive.org/web/20211113125901id_/http://au.search.yahoo.com/search?p=Bill+Callahan+(American+football)&ei=UTF-8&d=%7B%22dn%22%3A%22yk%22%2C%22ykid%22%3A%22d9b7247f-1d93-4148-a7cc-d7447903c37a%22+%7D&fr2=p%3As%2Cv%3Aw%2Cm%3Akg-pasf%2Cct%3AGetPersonInfo&fr=fp-tts",
        "yahoo",
    )


def test_parse_query_yahoo_general_s_daughter_the_970749419():
    verify_serp_parsing(
        "https://web.archive.org/web/20001005123659id_/http://search.yahoo.com:80/search?p=General's+Daughter,+The",
        "yahoo",
    )


def test_parse_query_yahoo_golson_1017320115():
    verify_serp_parsing(
        "https://web.archive.org/web/20020328125515id_/http://search.yahoo.com:80/search?p=golson",
        "yahoo",
    )


def test_parse_query_yahoo_golden_books_971368161():
    verify_serp_parsing(
        "https://web.archive.org/web/20001012162921id_/http://search.yahoo.com:80/search?p=golden+books",
        "yahoo",
    )


def test_parse_query_yahoo_girlsandanimals_1039016411():
    verify_serp_parsing(
        "https://web.archive.org/web/20021204154011id_/http://search.yahoo.com:80/search?p=girlsandanimals",
        "yahoo",
    )


def test_parse_query_yahoo_ganze_filme_online_schauen_kostenlos_und_in_voller_lange_1376615487():
    verify_serp_parsing(
        "https://web.archive.org/web/20130816011127id_/http://search.yahoo.com/search?p=Ganze+Filme+online+schauen+kostenlos+und+in+voller+L%C3%A4nge",
        "yahoo",
    )


def test_parse_query_yahoo_full_speed_1011203807():
    verify_serp_parsing(
        "https://web.archive.org/web/20020116175647id_/http://search.yahoo.com:80/search?p=Full+Speed",
        "yahoo",
    )


def test_parse_query_yahoo_future_of_sport_971016077():
    verify_serp_parsing(
        "https://web.archive.org/web/20001008144117id_/http://search.yahoo.com:80/search?p=future+of+sport",
        "yahoo",
    )


def test_parse_query_yahoo_george_foreman_boxer_1040476713():
    verify_serp_parsing(
        "https://web.archive.org/web/20021221131833id_/http://search.yahoo.com:80/search?p=george+foreman+boxer",
        "yahoo",
    )


def test_parse_query_yahoo_gogi_grant_1041483222():
    verify_serp_parsing(
        "https://web.archive.org/web/20030102045342id_/http://search.yahoo.com:80/search?p=Gogi+Grant",
        "yahoo",
    )


def test_parse_query_yahoo_ghulam_sarwar_khan_1626337646():
    verify_serp_parsing(
        "https://web.archive.org/web/20210715082726id_/https://search.yahoo.com/search?p=Ghulam%20Sarwar%20Khan",
        "yahoo",
    )


def test_parse_query_yahoo_free_mail_centers_970285370():
    verify_serp_parsing(
        "https://web.archive.org/web/20000930034250id_/http://search.yahoo.com:80/search?p=FREE+MAIL+CENTERS",
        "yahoo",
    )


def test_parse_query_yahoo_games_970945905():
    verify_serp_parsing(
        "https://web.archive.org/web/20001007191145id_/http://search.yahoo.com:80/search?p=gAmes",
        "yahoo",
    )


def test_parse_query_yahoo_gamespot_portugal_1036145291():
    verify_serp_parsing(
        "https://web.archive.org/web/20021101100811id_/http://search.yahoo.com:80/search?p=gamespot+portugal",
        "yahoo",
    )


def test_parse_query_yahoo_gay_shower_sex_961542771():
    verify_serp_parsing(
        "https://web.archive.org/web/20000620231251id_/http://search.yahoo.com:80/search?p=gay+shower+sex",
        "yahoo",
    )


def test_parse_query_yahoo_golf_poll_971193897():
    verify_serp_parsing(
        "https://web.archive.org/web/20001010160457id_/http://search.yahoo.com:80/search?p=golf+poll",
        "yahoo",
    )


def test_parse_query_yahoo_envious_that_biden_1652739375():
    verify_serp_parsing(
        "https://web.archive.org/web/20220516221615id_/https://search.yahoo.com/search?p=envious+that+biden&ei=UTF-8&fr2=time&age=1d&btf=d&fr=sfp",
        "yahoo",
    )


def test_parse_query_yahoo_genserv_971364933():
    verify_serp_parsing(
        "https://web.archive.org/web/20001012153533id_/http://search.yahoo.com:80/search?p=genserv",
        "yahoo",
    )


def test_parse_query_yahoo_every_previewsworld_calls_1649106369():
    verify_serp_parsing(
        "https://web.archive.org/web/20220404210609id_/https://search.yahoo.com/search?p=every+previewsworld+calls&ei=UTF-8&fr2=time&age=1d&btf=d&fr=sfp",
        "yahoo",
    )


def test_parse_query_yahoo_frugal_994624570():
    verify_serp_parsing(
        "https://web.archive.org/web/20010708203610id_/http://search.yahoo.com:80/search?p=Frugal",
        "yahoo",
    )


def test_parse_query_yahoo_hombres_con_pelo_en_el_pecho_photos_1359853955():
    verify_serp_parsing(
        "https://web.archive.org/web/20130203011235id_/http://au.search.yahoo.com/search?p=hombres+con+pelo+en+el+pecho+photos&fr2=sb-top&fr=404&type_param=",
        "yahoo",
    )


def test_parse_query_yahoo_free_pics_bbbw_1041625676():
    verify_serp_parsing(
        "https://web.archive.org/web/20030103202756id_/http://search.yahoo.com:80/search?p=free+pics+bbbw",
        "yahoo",
    )


def test_parse_query_yahoo_funny_970842855():
    verify_serp_parsing(
        "https://web.archive.org/web/20001006143415id_/http://search.yahoo.com:80/search?p=FUNNY",
        "yahoo",
    )


def test_parse_query_yahoo_gender_discrimination_970694307():
    verify_serp_parsing(
        "https://web.archive.org/web/20001004211827id_/http://search.yahoo.com:80/search?p=gender+discrimination+",
        "yahoo",
    )


def test_parse_query_yahoo_gaming_club_997142327():
    verify_serp_parsing(
        "https://web.archive.org/web/20010806235847id_/http://search.yahoo.com:80/search?p=gaming+club",
        "yahoo",
    )


def test_parse_query_yahoo_gordon_bruce_955082521():
    verify_serp_parsing(
        "https://web.archive.org/web/20000407044201id_/http://search.yahoo.com:80/search?p=Gordon+Bruce",
        "yahoo",
    )


def test_parse_query_yahoo_freeware_936293306():
    verify_serp_parsing(
        "https://web.archive.org/web/19990902172826id_/http://search.yahoo.com:80/search?p=freeware",
        "yahoo",
    )


def test_parse_query_yahoo_funny_pictures_943791338():
    verify_serp_parsing(
        "https://web.archive.org/web/19991128121538id_/http://search.yahoo.com:80/search?p=funny+pictures",
        "yahoo",
    )


def test_parse_query_yahoo_free_nude_pics_of_brittney_spears_970473571():
    verify_serp_parsing(
        "https://web.archive.org/web/20001002075931id_/http://search.yahoo.com:80/search?p=free+nude+pics+of+Brittney+Spears",
        "yahoo",
    )


def test_parse_query_yahoo_games_video_games_developers_and_publishers_croteam_1624838167():
    verify_serp_parsing(
        "https://web.archive.org/web/20210627235607id_/https://search.yahoo.com/search?p=Games+Video+Games+Developers+and+Publishers+Croteam",
        "yahoo",
    )


def test_parse_query_yahoo_isnt_even_weirdest_thing_america_right_1653343893():
    verify_serp_parsing(
        "https://web.archive.org/web/20220523221133id_/https://search.yahoo.com/search?p=isnt+even+weirdest+thing+america+right&ei=UTF-8&fr2=time&age=1d&btf=d&fr=sfp",
        "yahoo",
    )


def test_parse_query_yahoo_georgetown_university_law_center_970779220():
    verify_serp_parsing(
        "https://web.archive.org/web/20001005205340id_/http://search.yahoo.com:80/search?p=Georgetown+University+Law+Center",
        "yahoo",
    )


def test_parse_query_yahoo_wheatstone_bridge_1613009822():
    verify_serp_parsing(
        "https://web.archive.org/web/20210211021702id_/https://au.search.yahoo.com/search?p=wheatstone+bridge&fr=my_top",
        "yahoo",
    )


def test_parse_query_yahoo_fresh_prince_of_bel_air_971413040():
    verify_serp_parsing(
        "https://web.archive.org/web/20001013045720id_/http://search.yahoo.com:80/search?p=Fresh+Prince+of+Bel+Air",
        "yahoo",
    )


def test_parse_query_yahoo_mark_schlissel_wife_1642367070():
    verify_serp_parsing(
        "https://web.archive.org/web/20220116210430id_/http://au.search.yahoo.com/search?p=mark+schlissel+wife&ei=UTF-8&nojs=1",
        "yahoo",
    )


def test_parse_query_yahoo_games_puzzles_brain_teasers_sudoku_1574052323():
    verify_serp_parsing(
        "https://web.archive.org/web/20191118044523id_/https://search.yahoo.com/search?p=Games+Puzzles+Brain+Teasers+Sudoku",
        "yahoo",
    )


def test_parse_query_yahoo_gaelic_970435492():
    verify_serp_parsing(
        "https://web.archive.org/web/20001001212452id_/http://search.yahoo.com:80/search?p=Gaelic",
        "yahoo",
    )


def test_parse_query_yahoo_free_xxx_asian_pics_952102259():
    verify_serp_parsing(
        "https://web.archive.org/web/20000303165059id_/http://search.yahoo.com:80/search?p=Free+XXX+asian+pics",
        "yahoo",
    )


def test_parse_query_yahoo_german_pen_pals_961119166():
    verify_serp_parsing(
        "https://web.archive.org/web/20000616013246id_/http://search.yahoo.com:80/search?p=german+pen+pals",
        "yahoo",
    )


def test_parse_query_yahoo_goddess_955975798():
    verify_serp_parsing(
        "https://web.archive.org/web/20000417124958id_/http://search.yahoo.com:80/search?p=Goddess",
        "yahoo",
    )


def test_parse_query_yahoo_govote_com_955100292():
    verify_serp_parsing(
        "https://web.archive.org/web/20000407093812id_/http://search.yahoo.com:80/search?p=govote.com",
        "yahoo",
    )


def test_parse_query_yahoo_trans_texas_corridor_1613259804():
    verify_serp_parsing(
        "https://web.archive.org/web/20210213234324id_/https://au.search.yahoo.com/search?p=trans+texas+corridor&fr=ush-groups",
        "yahoo",
    )


def test_parse_query_yahoo_ghar_1005251824():
    verify_serp_parsing(
        "https://web.archive.org/web/20011108203704id_/http://search.yahoo.com:80/search?p=Ghar",
        "yahoo",
    )


def test_parse_query_yahoo_global_and_parts_970542388():
    verify_serp_parsing(
        "https://web.archive.org/web/20001003030628id_/http://search.yahoo.com:80/search?p=global+and+parts",
        "yahoo",
    )


def test_parse_query_yahoo_georgia_restaurant_association_970314665():
    verify_serp_parsing(
        "https://web.archive.org/web/20000930115105id_/http://search.yahoo.com:80/search?p=Georgia+Restaurant+Association",
        "yahoo",
    )
