/* eslint-disable */
/* prettier-ignore */
// @ts-nocheck
// Generated by unplugin-vue-components
// Read more: https://github.com/vuejs/core/pull/3399
export {}

declare module 'vue' {
  export interface GlobalComponents {
    Footer: typeof import('./src/components/Footer.vue')['default']
    Header: typeof import('./src/components/Header.vue')['default']
    Home: typeof import('./src/components/Home.vue')['default']
    ProgressTable: typeof import('./src/components/ProgressTable.vue')['default']
    StatisticsTable: typeof import('./src/components/StatisticsTable.vue')['default']
  }
}
