# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_indeed_origins_macy_s_1353165507():
    verify_serp_parsing(
        "https://web.archive.org/web/20121117151827id_/http://www.indeed.com/jobs?q=Origins%2Fmacy%27s",
        "indeed",
    )


def test_parse_query_indeed_hca_corporate_1334425152():
    verify_serp_parsing(
        "https://web.archive.org/web/20120414173912id_/http://www.indeed.com/jobs?q=HCA-Corporate&l=Orlando,+FL",
        "indeed",
    )


def test_parse_query_indeed_60000_1450529560():
    verify_serp_parsing(
        "https://web.archive.org/web/20151219125240id_/http://www.indeed.com/jobs?q=$60,000&l=Saratoga,+CA&sort=date",
        "indeed",
    )


def test_parse_query_indeed_concept_development_integration_1647187061():
    verify_serp_parsing(
        "https://web.archive.org/web/20220313155741id_/https://de.indeed.com/jobs?q=Concept+Development+Integration&l=M%C3%BCnchen",
        "indeed",
    )


def test_parse_query_indeed_jvm_lending_1586272513():
    verify_serp_parsing(
        "https://web.archive.org/web/20200407151513id_/https://www.indeed.com/jobs?q=JVM+Lending&rbl=Salt+Lake+City,+UT&jlid=029db43e55e0cfca",
        "indeed",
    )


def test_parse_query_indeed_customer_service_1447983624():
    verify_serp_parsing(
        "https://web.archive.org/web/20151120014024id_/http://www.indeed.com/jobs?q=Customer+Service&rbl=Phoenix,+AZ&jlid=b4ff2ac66b411fd8",
        "indeed",
    )


def test_parse_query_indeed_higher_education_freelance_network_1585036169():
    verify_serp_parsing(
        "https://web.archive.org/web/20200324074929id_/https://www.indeed.com/jobs?q=Higher+Education+Freelance+Network&rbc=The+University+of+Chicago&jcid=5cb727313a823dd6",
        "indeed",
    )


def test_parse_query_indeed_steiner_business_solutions_1577184429():
    verify_serp_parsing(
        "https://web.archive.org/web/20191224104709id_/https://www.indeed.com/jobs?q=Steiner+Business+Solutions&explvl=mid_level",
        "indeed",
    )


def test_parse_query_indeed_international_english_prep_academy_iepa_1586237411():
    verify_serp_parsing(
        "https://web.archive.org/web/20200407053011id_/https://www.indeed.com/jobs?q=International+English+Prep+Academy+(iepa)&l=Stafford,+VA&nc=jasx",
        "indeed",
    )


def test_parse_query_indeed_pepsico_1487893385():
    verify_serp_parsing(
        "https://web.archive.org/web/20170223234305id_/http://www.indeed.com/jobs?q=PepsiCo&jt=contract",
        "indeed",
    )
