# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_roblox_survival_1656759229():
    verify_serp_parsing(
        "https://web.archive.org/web/20220702105349id_/https://www.roblox.com/discover/?Keyword=survival",
        "roblox",
    )


def test_parse_query_roblox_survive_the_killer_1640549700():
    verify_serp_parsing(
        "https://web.archive.org/web/20211226201500id_/https://www.roblox.com/discover/?Keyword=survive+the+killer",
        "roblox",
    )


def test_parse_query_roblox_chernobyl_rp_1666555966():
    verify_serp_parsing(
        "https://web.archive.org/web/20221023201246id_/https://www.roblox.com/discover/?Keyword=chernobyl%20rp",
        "roblox",
    )


def test_parse_query_roblox_shorts_1357668619():
    verify_serp_parsing(
        "https://web.archive.org/web/20130108181019id_/http://www.roblox.com:80/catalog/browse.aspx?Subcategory=13&Keyword=shorts&LegendExpanded=true&Category=3",
        "roblox",
    )


def test_parse_query_roblox_xo_so_88_gg8_run_1659417607():
    verify_serp_parsing(
        "https://web.archive.org/web/20220802052007id_/https://www.roblox.com/discover/?Keyword=x%E1%BB%95%20s%E1%BB%91%2088%20GG8.Run",
        "roblox",
    )


def test_parse_query_roblox_welcome_to_the_town_of_robloxia_uncopylocked_1660007534():
    verify_serp_parsing(
        "https://web.archive.org/web/20220809011214id_/https://www.roblox.com/discover/?Keyword=welcome%20to%20the%20town%20of%20robloxia%20uncopylocked",
        "roblox",
    )


def test_parse_query_roblox_build_to_survive_black_people_1663785067():
    verify_serp_parsing(
        "https://web.archive.org/web/20220921183107id_/https://www.roblox.com/discover/?Keyword=build%20to%20survive%20black%20people",
        "roblox",
    )


def test_parse_query_roblox_cut_1633682743():
    verify_serp_parsing(
        "https://web.archive.org/web/20211008084543id_/https://www.roblox.com/discover/?Keyword=cut",
        "roblox",
    )


def test_parse_query_roblox_znation8000_1650350926():
    verify_serp_parsing(
        "https://web.archive.org/web/20220419064846id_/https://www.roblox.com/discover/?Keyword=znation8000",
        "roblox",
    )


def test_parse_query_roblox_soviet_union_1657601847():
    verify_serp_parsing(
        "https://web.archive.org/web/20220712045727id_/https://www.roblox.com/discover/?Keyword=soviet+union",
        "roblox",
    )
