# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_canva_instagram_reels_video_1607594697():
    verify_serp_parsing(
        "https://web.archive.org/web/20201210100457id_/https://www.canva.com/design/play?category=tAEEZ_gIPxM&template=EAD_mTZpt2k&type=TAD9VKDO5tI&layoutQuery=Instagram%20Reels%20Video&analyticsCorrelationId=f6767fc3-7f33-445e-9740-a004311e5afe",
        "canva",
    )
