# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_espn_ball_state_1619440827():
    verify_serp_parsing(
        "https://web.archive.org/web/20210426124027id_/https://www.espn.com/search/_/q/Ball%20State/o/watch",
        "espn",
    )


def test_parse_query_espn_ball_state_1615730301():
    verify_serp_parsing(
        "https://web.archive.org/web/20210314135821id_/https://www.espn.com/search/_/q/Ball%20State/o/watch",
        "espn",
    )
