# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_sogou_lofke_yi_kua_shi_chang_mai_mai_1333092705():
    verify_serp_parsing(
        "https://web.archive.org/web/20120330073145id_/http://www.sogou.com/web?query=lof%E5%8F%AF%E4%BB%A5%E8%B7%A8%E5%B8%82%E5%9C%BA%E4%B9%B0%E5%8D%96&p=02210102&fhintidx=7",
        "sogou",
    )


def test_parse_query_sogou_xing_ai_ji_qiao_1576522689():
    verify_serp_parsing(
        "https://web.archive.org/web/20191216185809id_/https://www.sogou.com/sogou?query=%E6%80%A7%E7%88%B1%E6%8A%80%E5%B7%A7&ie=utf8&insite=baike.sogou.com&pid=sogou-wsse-17737832ac17be52",
        "sogou",
    )


def test_parse_query_sogou_j_1341637724():
    verify_serp_parsing(
        "https://web.archive.org/web/20120707050844id_/http://www.sogou.com:80/web?query=%D7%F6%BF%D5%BB%FA%B9%B9%CF%E3%E9%DA&p=31210100&fhintidx=3",
        "sogou",
    )


def test_parse_query_sogou_ju_min_shen_fen_zheng_hao_ma_he_xing_ming_1508756794():
    verify_serp_parsing(
        "https://web.archive.org/web/20171023110634id_/http://www.sogou.com/sogou?user_ip=207.241.229.48&sourceid=hint&bh=1&hintidx=11&query=%E5%B1%85%E6%B0%91%E8%BA%AB%E4%BB%BD%E8%AF%81%E5%8F%B7%E7%A0%81%E5%92%8C%E5%A7%93%E5%90%8D&pid=sogou-site-d54ce9de9df77c57&duppid=1&w=01020600&interation=&interV=kKIOkrELjboLmLkEkLoTkKIMkrELjboImLkEk74TkKILmrELjb8TkKIKmrELjbkI_-1099283536&htdbg=idc%3Ebjdjt%7CdbgID%3E01%7Cabt%3E0%7Cmth%3E1&ie=utf8&s_from=hint_last",
        "sogou",
    )


def test_parse_query_sogou_yuan_dai_ma_xie_lu_1578201651():
    verify_serp_parsing(
        "https://web.archive.org/web/20200105052051id_/https://www.sogou.com/sogou?pid=sogou-wsse-ff111e4a5406ed40&insite=zhihu.com&p=42351201&query=%E6%BA%90%E4%BB%A3%E7%A0%81%E6%B3%84%E9%9C%B2&ie=utf8&p=42351201&query=%E6%BA%90%E4%BB%A3%E7%A0%81%E6%B3%84%E9%9C%B2&ie=utf8",
        "sogou",
    )


def test_parse_query_sogou_cesuk_163163163_cn_1493482889():
    verify_serp_parsing(
        "https://web.archive.org/web/20170429162129id_/http://www.sogou.com/sogou?pid=sogou-wsse-3f7bcd0b3ea82268&ie=utf-8&query=cesuk.163163163.cn",
        "sogou",
    )


def test_parse_query_sogou_l_1346233371():
    verify_serp_parsing(
        "https://web.archive.org/web/20120829094251id_/http://www.sogou.com:80/web?query=%BF%F7%CB%F0%B9%FD%B5%C4%B9%CC%B6%A8%CA%D5%D2%E6%D0%C5%CD%D0&p=02210102&fhintidx=7",
        "sogou",
    )


def test_parse_query_sogou_eed_1_4a1_a_1332923188():
    verify_serp_parsing(
        "https://web.archive.org/web/20120328082628id_/http://www.sogou.com/web?query=%C2%B1%C3%88%C3%88%C3%B0%C2%BC%C2%AA%C2%B9%C2%B7%C3%81%C2%B8&p=03210100",
        "sogou",
    )


def test_parse_query_sogou_ti_gong_jin_kou_qi_qiang_1647324224():
    verify_serp_parsing(
        "https://web.archive.org/web/20220315060344id_/https://www.sogou.com/web?query=%E6%8F%90%E4%BE%9B%E8%BF%9B%E5%8F%A3%E6%B0%94%E6%9E%AA&ie=utf8",
        "sogou",
    )


def test_parse_query_sogou_tu_guan_xin_gai_kuan_1332227339():
    verify_serp_parsing(
        "https://web.archive.org/web/20120320070859id_/http://www.sogou.com/web?query=%E9%80%94%E8%A7%82%E6%96%B0%E6%94%B9%E6%AC%BE&p=02210102&fhintidx=3",
        "sogou",
    )
