# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_github_topic_deprecated_org_bandwidth_fork_true_1634361552():
    verify_serp_parsing(
        "https://web.archive.org/web/20211016051912id_/https://github.com/search?q=topic%3Adeprecated+org%3ABandwidth+fork%3Atrue",
        "github",
    )


def test_parse_query_github_topic_docker_stack_org_issuu_1549097482():
    verify_serp_parsing(
        "https://web.archive.org/web/20190202085122id_/https://github.com/search?q=topic%3Adocker-stack+org%3Aissuu&type=Users",
        "github",
    )


def test_parse_query_github_topic_web_components_org_github_fork_true_1650012538():
    verify_serp_parsing(
        "https://web.archive.org/web/20220415084858id_/https://github.com/search?q=topic%3Aweb-components+org%3Agithub+fork%3Atrue",
        "github",
    )


def test_parse_query_github_topic_id_org_codercom_1553274306():
    verify_serp_parsing(
        "https://web.archive.org/web/20190322170506id_/https://github.com/search?q=topic%3Aid+org%3Acodercom&type=Repositories",
        "github",
    )


def test_parse_query_github_mastodon_1657854340():
    verify_serp_parsing(
        "https://web.archive.org/web/20220715030540id_/https://github.com/search?q=mastodon&type=registrypackages",
        "github",
    )


def test_parse_query_github_licensing_gethhwid_1662581846():
    verify_serp_parsing(
        "https://web.archive.org/web/20220907201726id_/https://github.com/search?q=licensing_gethhwid&type=repositories",
        "github",
    )


def test_parse_query_github_subrock_1653099784():
    verify_serp_parsing(
        "https://web.archive.org/web/20220521022304id_/https://github.com/search?q=subrock",
        "github",
    )


def test_parse_query_github_jie_shi_de_jing_mi_gong_ye_you_xian_gong_si_1597737683():
    verify_serp_parsing(
        "https://web.archive.org/web/20200818080123id_/https://github.com/search?q=%E6%9D%B0%E5%A3%AB%E5%BE%B7%E7%B2%BE%E5%AF%86%E5%B7%A5%E4%B8%9A%E6%9C%89%E9%99%90%E5%85%AC%E5%8F%B8",
        "github",
    )


def test_parse_query_github_org_zettlr_1591675518():
    verify_serp_parsing(
        "https://web.archive.org/web/20200609040518id_/https://github.com/search?q=org%3AZettlr+",
        "github",
    )


def test_parse_query_github_topic_bootswatch_org_sslcom_1552777180():
    verify_serp_parsing(
        "https://web.archive.org/web/20190316225940id_/https://github.com/search?q=topic%3Abootswatch+org%3ASSLcom&type=Wikis",
        "github",
    )
