# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_ask_peter_krogh_photographer_1184320758():
    verify_serp_parsing(
        "https://web.archive.org/web/20070713095918id_/http://www.ask.com:80/web?q=Peter+Krogh+Photographer&o=0&qsrc=19&o=0",
        "ask",
    )


def test_parse_query_ask_preparation_of_offal_1172710460():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301005420id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Preparation+of+Offal",
        "ask",
    )


def test_parse_query_ask_tye_dye_instructions_1446417925():
    verify_serp_parsing(
        "https://web.archive.org/web/20151101224525id_/http://www.ask.com/web?q=Tye+Dye+Instructions&qsrc=466&o=13194&l=sem&qo=relatedSearchNarrow",
        "ask",
    )


def test_parse_query_ask_rhino_records_1173555865():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310194425id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Rhino+Records",
        "ask",
    )


def test_parse_query_ask_apologist_1172369538():
    verify_serp_parsing(
        "https://web.archive.org/web/20070225021218id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Apologist",
        "ask",
    )


def test_parse_query_ask_japanese_airlines_1173622069():
    verify_serp_parsing(
        "https://web.archive.org/web/20070311140749id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Japanese+Airlines",
        "ask",
    )


def test_parse_query_ask_whelped_definition_1173526805():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310114005id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Whelped+Definition",
        "ask",
    )


def test_parse_query_ask_what_s_california_s_state_bird_1175130217():
    verify_serp_parsing(
        "https://web.archive.org/web/20070329010337id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=What%27s+California%27s+State+Bird",
        "ask",
    )


def test_parse_query_ask_radioactivity_in_medicine_1173728275():
    verify_serp_parsing(
        "https://web.archive.org/web/20070312193755id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Radioactivity+in+Medicine",
        "ask",
    )


def test_parse_query_ask_free_grammer_test_for_employment_1443411312():
    verify_serp_parsing(
        "https://web.archive.org/web/20150928033512id_/http://www.ask.com:80/web?qsrc=1&o=15145&l=sem&q=free+grammer+test+for+employment",
        "ask",
    )


def test_parse_query_ask_meaning_of_integral_site_www_elook_org_1174247342():
    verify_serp_parsing(
        "https://web.archive.org/web/20070318194902id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=meaning+of+integral+site:www.elook.org",
        "ask",
    )


def test_parse_query_ask_week_names_1173639143():
    verify_serp_parsing(
        "https://web.archive.org/web/20070311185223id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Week+Names",
        "ask",
    )


def test_parse_query_ask_olympic_rings_1172716332():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301023212id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Olympic+Rings",
        "ask",
    )


def test_parse_query_ask_what_should_i_wear_on_the_first_day_of_school_1442349823():
    verify_serp_parsing(
        "https://web.archive.org/web/20150915204343id_/http://www.ask.com/web?qsrc=1&o=ffx&l=dir&q=What+should+I+wear+on+the+first+day+of+school%3F+",
        "ask",
    )


def test_parse_query_ask_genus_falco_1172718376():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301030616id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Genus+Falco",
        "ask",
    )


def test_parse_query_ask_what_words_rhyme_with_afraid_1173540494():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310152814id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=What+Words+Rhyme+with+Afraid%3F",
        "ask",
    )


def test_parse_query_ask_facula_site_www_wordreference_com_1173391757():
    verify_serp_parsing(
        "https://web.archive.org/web/20070308220917id_/http://www.ask.com:80/web?o=8001&qsrc=0&l=dir&q=facula+site:www.wordreference.com",
        "ask",
    )


def test_parse_query_ask_lopsided_site_www_usatoday_com_1173623642():
    verify_serp_parsing(
        "https://web.archive.org/web/20070311143402id_/http://www.ask.com:80/web?o=8001&qsrc=0&l=dir&q=lopsided+site:www.usatoday.com",
        "ask",
    )


def test_parse_query_ask_perfect_first_date_1180217842():
    verify_serp_parsing(
        "https://web.archive.org/web/20070526221722id_/http://www.ask.com:80/web?o=1159&qsrc=6&l=zr&q=Perfect+First+Date",
        "ask",
    )


def test_parse_query_ask_tie_dye_patterns_1446417858():
    verify_serp_parsing(
        "https://web.archive.org/web/20151101224418id_/http://www.ask.com/web?q=Tie+Dye+Patterns&qsrc=466&o=13194&l=sem&qo=relatedSearchNarrow",
        "ask",
    )


def test_parse_query_ask_cure_for_boredom_1174210645():
    verify_serp_parsing(
        "https://web.archive.org/web/20070318093725id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Cure+for+Boredom",
        "ask",
    )


def test_parse_query_ask_saiy_phiohom_1525375661():
    verify_serp_parsing(
        "https://web.archive.org/web/20180503192741id_/https://www.ask.com/web?q=Saiy+phiohom&x=49&y=0&qsrc=2300&o=1102&l=dir//",
        "ask",
    )


def test_parse_query_ask_i_ve_site_news_bbc_co_uk_1172693923():
    verify_serp_parsing(
        "https://web.archive.org/web/20070228201843id_/http://www.ask.com:80/web?o=8001&qsrc=0&l=dir&q=i've+site:news.bbc.co.uk",
        "ask",
    )


def test_parse_query_ask_dog_ear_design_1172708874():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301002754id_/http://www.ask.com:80/web?o=8002&qsrc=6&l=dir&q=Dog+Ear+Design",
        "ask",
    )


def test_parse_query_ask_big_tex_trailer_for_sale_1649774735():
    verify_serp_parsing(
        "https://web.archive.org/web/20220412144535id_/https://www.ask.com/web?q=Big+Tex+Trailer+for+Sale&qo=relatedSearchNarrow&o=1526&l=dis",
        "ask",
    )


def test_parse_query_ask_who_framed_roger_rabbit_1473167643():
    verify_serp_parsing(
        "https://web.archive.org/web/20160906131403id_/http://www.ask.com/web?q=Who+framed+roger+rabbit&qsrc=0&o=0&l=dir%2C+gset&qo=homepageSearchBox",
        "ask",
    )


def test_parse_query_ask_faither_site_www_accringtonweb_com_1173391901():
    verify_serp_parsing(
        "https://web.archive.org/web/20070308221141id_/http://www.ask.com:80/web?o=8001&qsrc=0&l=dir&q=faither++site:www.accringtonweb.com",
        "ask",
    )


def test_parse_query_ask_means_mutable_site_www_geek_interview_comrview_com_1173713625():
    verify_serp_parsing(
        "https://web.archive.org/web/20070312153345id_/http://www.ask.com:80/web?o=8001&qsrc=19&l=dir&q=means+mutable+site%3Awww.geek+interview.comrview.com",
        "ask",
    )


def test_parse_query_ask_date_guy_fawkes_death_1173527460():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310115100id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Date+Guy+Fawkes+Death",
        "ask",
    )


def test_parse_query_ask_interior_design_classes_online_1651218822():
    verify_serp_parsing(
        "https://web.archive.org/web/20220429075342id_/https://www.ask.com/web?q=Interior+Design+Classes+Online&qo=relatedSearchNarrow&o=21029&l=dis",
        "ask",
    )


def test_parse_query_ask_cell_biology_1173639673():
    verify_serp_parsing(
        "https://web.archive.org/web/20070311190113id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Cell+Biology",
        "ask",
    )


def test_parse_query_ask_www_ksu_edu_sa_1182367717():
    verify_serp_parsing(
        "https://web.archive.org/web/20070620192837id_/http://www.ask.com:80/web?o=1215&l=dis&q=www.ksu.edu.sa",
        "ask",
    )


def test_parse_query_ask_names_of_reggae_artists_1173527903():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310115823id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Names+of+Reggae+Artists",
        "ask",
    )


def test_parse_query_ask_vitamins_good_after_expiration_date_expires_site_www_cfs_purdue_edu_1173531858():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310130418id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=vitamins+good+after+expiration+date+expires+site:www.cfs.purdue.edu",
        "ask",
    )


def test_parse_query_ask_fachkunde_metall_fur_ausbildung_in_maschinenbauberufen_1461053109():
    verify_serp_parsing(
        "https://web.archive.org/web/20160419080509id_/http://www.ask.com:80/web?l=dir&qsrc=0&o=ffx&q=Fachkunde+Metall+f%C3%BCr+Ausbildung+in+Maschinenbauberufen",
        "ask",
    )


def test_parse_query_ask_weather_report_for_22903_1489829020():
    verify_serp_parsing(
        "https://web.archive.org/web/20170318092340id_/http://www.ask.com/web?q=weather+report+for+22903&qsrc=257&o=10285&l=iac",
        "ask",
    )


def test_parse_query_ask_old_fashioned_labels_1172720557():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301034237id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Old+Fashioned+Labels",
        "ask",
    )


def test_parse_query_ask_scorch_removal_1172719147():
    verify_serp_parsing(
        "https://web.archive.org/web/20070301031907id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Scorch+Removal",
        "ask",
    )


def test_parse_query_ask_means_mutable_site_www_geekinterview_com_1173392177():
    verify_serp_parsing(
        "https://web.archive.org/web/20070308221617id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=means+mutable+site:www.geekinterview.com",
        "ask",
    )


def test_parse_query_ask_batman_movie_1467834503():
    verify_serp_parsing(
        "https://web.archive.org/web/20160706194823id_/http://www.ask.com/web?q=batman+movie&qsrc=0&o=0&l=dir%2C+tr_uid&qo=homepageSearchBox",
        "ask",
    )


def test_parse_query_ask_if_you_break_a_fluorescent_light_bulb_1618021531():
    verify_serp_parsing(
        "https://web.archive.org/web/20210410022531id_/https://www.ask.com/web?q=if+you+break+a+fluorescent+light+bulb&qsrc=19&o=101881&l=dis",
        "ask",
    )


def test_parse_query_ask_five_phases_of_mitosis_1173539024():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310150344id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Five+Phases+of+Mitosis",
        "ask",
    )


def test_parse_query_ask_are_alkali_metals_lighter_than_water_1619387309():
    verify_serp_parsing(
        "https://web.archive.org/web/20210425214829id_/https://www.ask.com/web?q=Are+alkali+metals+lighter+than+water%3F&search=search&qsrc=178&o=ffx&l=dir",
        "ask",
    )


def test_parse_query_ask_failures_of_president_lincoln_1611567628():
    verify_serp_parsing(
        "https://web.archive.org/web/20210125094028id_/https://www.ask.com/web?q=Failures+of+President+Lincoln&qsrc=2384&o=tb&l=zn",
        "ask",
    )


def test_parse_query_ask_smirnoff_label_1173377085():
    verify_serp_parsing(
        "https://web.archive.org/web/20070308180445id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Smirnoff+Label",
        "ask",
    )


def test_parse_query_ask_boxer_ear_crop_1173516809():
    verify_serp_parsing(
        "https://web.archive.org/web/20070310085329id_/http://www.ask.com:80/web?o=8002&qsrc=6&l=dir&q=Boxer+Ear+Crop",
        "ask",
    )


def test_parse_query_ask_diaframma_contraccezione_lang_it_1175070504():
    verify_serp_parsing(
        "https://web.archive.org/web/20070328082824id_/http://www.ask.com:80/web?tt=1&q=diaframma+contraccezione+lang:IT&qsrc=23&nw=False&u=10",
        "ask",
    )


def test_parse_query_ask_caring_1173637789():
    verify_serp_parsing(
        "https://web.archive.org/web/20070311182949id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Caring",
        "ask",
    )


def test_parse_query_ask_http_my_notes_on_blogspot_com_1401243816():
    verify_serp_parsing(
        "https://web.archive.org/web/20140528022336id_/http://www.ask.com/web?qsrc=2&o=ffx&l=dir&q=%22http%3A%2F%2Fmy-notes-on.blogspot.com%2F%22",
        "ask",
    )


def test_parse_query_ask_afraid_of_women_1172618037():
    verify_serp_parsing(
        "https://web.archive.org/web/20070227231357id_/http://www.ask.com:80/web?o=8001&qsrc=6&l=dir&q=Afraid+of+Women",
        "ask",
    )
