# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_brave_chomikuj_1656776694():
    verify_serp_parsing(
        "https://web.archive.org/web/20220702154454id_/https://search.brave.com/search?q=chomikuj&spellcheck=0",
        "brave",
    )


def test_parse_query_brave_kymatica_1652976922():
    verify_serp_parsing(
        "https://web.archive.org/web/20220519161522id_/https://search.brave.com/search?q=Kymatica",
        "brave",
    )


def test_parse_query_brave_spigot_1660718390():
    verify_serp_parsing(
        "https://web.archive.org/web/20220817063950id_/https://search.brave.com/search?q=spigot",
        "brave",
    )


def test_parse_query_brave_import_esbuild_from_esbuild_syntaxerror_unexpected_identifier_1652662700():
    verify_serp_parsing(
        "https://web.archive.org/web/20220516005820id_/https://search.brave.com/search?q=import+esbuild+from+%22esbuild%22%3B++++++++%5E%5E%5E%5E%5E%5E%5E++SyntaxError%3A+Unexpected+identifier",
        "brave",
    )


def test_parse_query_brave_pizza_box_1662098145():
    verify_serp_parsing(
        "https://web.archive.org/web/20220902055545id_/https://search.brave.com/search?q=pizza%20box",
        "brave",
    )


def test_parse_query_brave_nvfbc_1651575025():
    verify_serp_parsing(
        "https://web.archive.org/web/20220503105025id_/https://search.brave.com/search?q=NvFBC&source=desktop",
        "brave",
    )


def test_parse_query_brave_jinniebella_1666397597():
    verify_serp_parsing(
        "https://web.archive.org/web/20221022001317id_/https://search.brave.com/search?q=jinniebella+&source=web",
        "brave",
    )


def test_parse_query_brave_67_degrees_c_static_atmosphere_1665006071():
    verify_serp_parsing(
        "https://web.archive.org/web/20221005214111id_/https://search.brave.com/search?q=67%20degrees%20C%20static%20atmosphere",
        "brave",
    )


def test_parse_query_brave_new_mac_os_release_1664483322():
    verify_serp_parsing(
        "https://web.archive.org/web/20220929202842id_/https://search.brave.com/search?q=new%20mac%20os%20release",
        "brave",
    )


def test_parse_query_brave_bivoks_trebehandling_1654325149():
    verify_serp_parsing(
        "https://web.archive.org/web/20220604064549id_/https://search.brave.com/search?q=bivoks+trebehandling",
        "brave",
    )


def test_parse_query_brave_google_play_store_1649985658():
    verify_serp_parsing(
        "https://web.archive.org/web/20220415012058id_/https://search.brave.com/search?q=google+play+store&source=web",
        "brave",
    )


def test_parse_query_brave_pekara_fontana_niksic_1649235416():
    verify_serp_parsing(
        "https://web.archive.org/web/20220406085656id_/https://search.brave.com/search?q=pekara+fontana+nik%C5%A1i%C4%87",
        "brave",
    )


def test_parse_query_brave_avnon_dan_1998_martin_buber_the_hidden_dialogue_lanham_boulder_new_york_oxford_rowman_littlefield_1649576842():
    verify_serp_parsing(
        "https://web.archive.org/web/20220410074722id_/https://search.brave.com/search?q=Avnon%2C+Dan%2C+1998%2C+Martin+Buber.+The+Hidden+Dialogue%2C+Lanham%2C+Boulder%2C+New+York%2C+Oxford%3A+Rowman+%26+Littlefield.",
        "brave",
    )


def test_parse_query_brave_metaverse_1650224042():
    verify_serp_parsing(
        "https://web.archive.org/web/20220417193402id_/https://search.brave.com/search?q=%EF%BF%BDmetaverse",
        "brave",
    )


def test_parse_query_brave_h_m_home_1664916031():
    verify_serp_parsing(
        "https://web.archive.org/web/20221004204031id_/https://search.brave.com/search?q=h%26m%20home&spellcheck=0",
        "brave",
    )


def test_parse_query_brave_utilitx_1659649168():
    verify_serp_parsing(
        "https://web.archive.org/web/20220804213928id_/https://search.brave.com/search?q=Utilitx",
        "brave",
    )


def test_parse_query_brave_how_tot_ell_if_tail_recurssive_1658814198():
    verify_serp_parsing(
        "https://web.archive.org/web/20220726054318id_/https://search.brave.com/search?q=how+tot+ell+if+tail+recurssive",
        "brave",
    )


def test_parse_query_brave_random_number_python_1649475875():
    verify_serp_parsing(
        "https://web.archive.org/web/20220409034435id_/https://search.brave.com/search?q=random+number+python&source=desktop",
        "brave",
    )


def test_parse_query_brave_dark_brown_mushrooms_that_melt_in_to_the_ground_1657827723():
    verify_serp_parsing(
        "https://web.archive.org/web/20220714194203id_/https://search.brave.com/search?q=dark+brown+mushrooms+that+melt+in+to+the+ground",
        "brave",
    )


def test_parse_query_brave_a2z_chip_1632000373():
    verify_serp_parsing(
        "https://web.archive.org/web/20210918212613id_/https://search.brave.com/search?q=A2Z+chip",
        "brave",
    )


def test_parse_query_brave_video_1649793956():
    verify_serp_parsing(
        "https://web.archive.org/web/20220412200556id_/https://search.brave.com/search?q=Video",
        "brave",
    )


def test_parse_query_brave_tina_daunt_1652776164():
    verify_serp_parsing(
        "https://web.archive.org/web/20220517082924id_/https://search.brave.com/search?q=tina+daunt",
        "brave",
    )


def test_parse_query_brave_ape_1648509867():
    verify_serp_parsing(
        "https://web.archive.org/web/20220328232427id_/https://search.brave.com/search?q=Ape",
        "brave",
    )


def test_parse_query_brave_nair_1666404375():
    verify_serp_parsing(
        "https://web.archive.org/web/20221022020615id_/https://search.brave.com/search?q=nair",
        "brave",
    )


def test_parse_query_brave_virtualbox_extensions_1667278528():
    verify_serp_parsing(
        "https://web.archive.org/web/20221101045528id_/https://search.brave.com/search?q=virtualbox%20extensions",
        "brave",
    )


def test_parse_query_brave_best_notetaking_app_1654643212():
    verify_serp_parsing(
        "https://web.archive.org/web/20220607230652id_/https://search.brave.com/search?q=best+notetaking+app",
        "brave",
    )


def test_parse_query_brave_logitech_1661137612():
    verify_serp_parsing(
        "https://web.archive.org/web/20220822030652id_/https://search.brave.com/search?q=logitech&source=web",
        "brave",
    )


def test_parse_query_brave_advanced_search_query_1667410105():
    verify_serp_parsing(
        "https://web.archive.org/web/20221102172825id_/https://search.brave.com/search?q=advanced-search-query",
        "brave",
    )


def test_parse_query_brave_froggy_pool_1651139840():
    verify_serp_parsing(
        "https://web.archive.org/web/20220428095720id_/https://search.brave.com/search?q=froggy+pool&source=desktop",
        "brave",
    )


def test_parse_query_brave_new_fold_4_1657628120():
    verify_serp_parsing(
        "https://web.archive.org/web/20220712121520id_/https://search.brave.com/search?q=new+fold+4&source=web",
        "brave",
    )


def test_parse_query_brave_maintenance_1661082520():
    verify_serp_parsing(
        "https://web.archive.org/web/20220821114840id_/https://search.brave.com/search?q=maintenance",
        "brave",
    )


def test_parse_query_brave_product_life_cycle_definition_1664819445():
    verify_serp_parsing(
        "https://web.archive.org/web/20221003175045id_/https://search.brave.com/search?q=product%20life%20cycle%20definition",
        "brave",
    )


def test_parse_query_brave_indiana_vaccine_passport_ban_1629877535():
    verify_serp_parsing(
        "https://web.archive.org/web/20210825074535id_/https://search.brave.com/search?q=Indiana+vaccine+passport+ban",
        "brave",
    )


def test_parse_query_brave_terraform_github_container_1666470147():
    verify_serp_parsing(
        "https://web.archive.org/web/20221022202227id_/https://search.brave.com/search?q=terraform%20github%20container",
        "brave",
    )


def test_parse_query_brave_safemoon_1653585598():
    verify_serp_parsing(
        "https://web.archive.org/web/20220526171958id_/https://search.brave.com/search?q=safemoon",
        "brave",
    )


def test_parse_query_brave_usb_3_1_type_c_dp_alt_mode_1667002333():
    verify_serp_parsing(
        "https://web.archive.org/web/20221029001213id_/https://search.brave.com/search?q=USB+3.1+Type+C+DP+ALT-MODE&source=desktop",
        "brave",
    )


def test_parse_query_brave_copyq_1665902945():
    verify_serp_parsing(
        "https://web.archive.org/web/20221016064905id_/https://search.brave.com/search?q=CopyQ",
        "brave",
    )


def test_parse_query_brave_rent_1647905724():
    verify_serp_parsing(
        "https://web.archive.org/web/20220321233524id_/https://search.brave.com/search?q=Rent",
        "brave",
    )


def test_parse_query_brave_openoffice_1667290210():
    verify_serp_parsing(
        "https://web.archive.org/web/20221101081010id_/https://search.brave.com/search?q=OpenOffice",
        "brave",
    )


def test_parse_query_brave_apple_t3_chip_1651405075():
    verify_serp_parsing(
        "https://web.archive.org/web/20220501113755id_/https://search.brave.com/search?q=apple+t3+chip",
        "brave",
    )


def test_parse_query_brave_how_to_archive_mac_notes_1658260525():
    verify_serp_parsing(
        "https://web.archive.org/web/20220719195525id_/https://search.brave.com/search?q=how+to+archive+mac+notes&source=desktop",
        "brave",
    )


def test_parse_query_brave_amoled_1646168352():
    verify_serp_parsing(
        "https://web.archive.org/web/20220301205912id_/https://search.brave.com/search?q=AMOLED",
        "brave",
    )


def test_parse_query_brave_testimonies_project_1653158644():
    verify_serp_parsing(
        "https://web.archive.org/web/20220521184404id_/https://search.brave.com/search?q=testimonies+project&source=desktop",
        "brave",
    )


def test_parse_query_brave_fastest_otto_guide_1649849902():
    verify_serp_parsing(
        "https://web.archive.org/web/20220413113822id_/https://search.brave.com/search?q=fastest+otto+guide&source=desktop",
        "brave",
    )


def test_parse_query_brave_greentext_1664484724():
    verify_serp_parsing(
        "https://web.archive.org/web/20220929205204id_/https://search.brave.com/search?q=greentext",
        "brave",
    )


def test_parse_query_brave_house_building_cost_estimate_1664320455():
    verify_serp_parsing(
        "https://web.archive.org/web/20220927231415id_/https://search.brave.com/search?q=house%20building%20cost%20estimate",
        "brave",
    )


def test_parse_query_brave_cubecraft_skyblock_pig_farm_1664124008():
    verify_serp_parsing(
        "https://web.archive.org/web/20220925164008id_/https://search.brave.com/search?q=CubeCraft+Skyblock+pig+farm&source=desktop",
        "brave",
    )


def test_parse_query_brave_masi_uno_riser_chain_cover_1658006343():
    verify_serp_parsing(
        "https://web.archive.org/web/20220716211903id_/https://search.brave.com/search?q=masi+uno+riser+chain+cover",
        "brave",
    )


def test_parse_query_brave_unremovable_1650484694():
    verify_serp_parsing(
        "https://web.archive.org/web/20220420195814id_/https://search.brave.com/search?q=unremovable",
        "brave",
    )


def test_parse_query_brave_troll_1649987736():
    verify_serp_parsing(
        "https://web.archive.org/web/20220415015536id_/https://search.brave.com/search?q=troll",
        "brave",
    )
