# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_vk_technology_1383988940():
    verify_serp_parsing(
        "https://web.archive.org/web/20131109092220id_/http://vk.com/search?c%5Bq%5D=technology&c%5Bsection%5D=people&offset=0",
        "vk",
    )


def test_parse_query_vk_000_space_marine_1363614912():
    verify_serp_parsing(
        "https://web.archive.org/web/20130318135512id_/http://vk.com/search?c%5Bq%5D=000%3A%20Space%20Marine&c%5Bsection%5D=people&offset=10640",
        "vk",
    )


def test_parse_query_vk_gta_1389323282():
    verify_serp_parsing(
        "https://web.archive.org/web/20140110030802id_/http://vk.com/search?c%5Bq%5D=GTA&c%5Bsection%5D=people&offset=20",
        "vk",
    )


def test_parse_query_vk_radioelektronnye_sistemy_1361402773():
    verify_serp_parsing(
        "https://web.archive.org/web/20130220232613id_/http://vk.com/search?c[name]=0&c[section]=people&c[q]=%D1%80%D0%B0%D0%B4%D0%B8%D0%BE%D1%8D%D0%BB%D0%B5%D0%BA%D1%82%D1%80%D0%BE%D0%BD%D0%BD%D1%8B%D0%B5%20%D1%81%D0%B8%D1%81%D1%82%D0%B5%D0%BC%D1%8B",
        "vk",
    )


def test_parse_query_vk_rabotaiu_na_sebia_1361533546():
    verify_serp_parsing(
        "https://web.archive.org/web/20130222114546id_/http://vk.com/search?c%5Bq%5D=%D1%80%D0%B0%D0%B1%D0%BE%D1%82%D0%B0%D1%8E%20%D0%BD%D0%B0%20%D1%81%D0%B5%D0%B1%D1%8F&c%5Bsection%5D=people&offset=20",
        "vk",
    )


def test_parse_query_vk_imperatory_illiuzii_1387125239():
    verify_serp_parsing(
        "https://web.archive.org/web/20131215163359id_/http://vk.com/search?c[name]=0&c[section]=people&c[q]=%D0%98%D0%BC%D0%BF%D0%B5%D1%80%D0%B0%D1%82%D0%BE%D1%80%D1%8B%20%D0%B8%D0%BB%D0%BB%D1%8E%D0%B7%D0%B8%D0%B9",
        "vk",
    )


def test_parse_query_vk_loco_roco_1377325114():
    verify_serp_parsing(
        "https://web.archive.org/web/20130824061834id_/http://vk.com/search?c[name]=0&c[section]=people&c[q]=Loco%20Roco",
        "vk",
    )


def test_parse_query_vk_sportivnye_mototsikly_1387080107():
    verify_serp_parsing(
        "https://web.archive.org/web/20131215040147id_/http://vk.com/search?c[name]=0&c[section]=people&c[q]=%D1%81%D0%BF%D0%BE%D1%80%D1%82%D0%B8%D0%B2%D0%BD%D1%8B%D0%B5%20%D0%BC%D0%BE%D1%82%D0%BE%D1%86%D0%B8%D0%BA%D0%BB%D1%8B",
        "vk",
    )


def test_parse_query_vk_grot_1353834377():
    verify_serp_parsing(
        "https://web.archive.org/web/20121125090617id_/http://vk.com:80/search?c%5Bq%5D=%D0%B3%D1%80%D0%BE%D1%82&c%5Bsection%5D=auto",
        "vk",
    )


def test_parse_query_vk_muzyka_1372304839():
    verify_serp_parsing(
        "https://web.archive.org/web/20130627034719id_/http://vk.com/search?c%5Bq%5D=%D0%9C%D0%A3%D0%97%D0%AB%D0%9A%D0%90&c%5Bsection%5D=people&offset=0",
        "vk",
    )
