# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_weibo_sheng_fu_lang_xi_si_1603546157():
    verify_serp_parsing(
        "https://web.archive.org/web/20201024132917id_/https://s.weibo.com/weibo?q=%23%E5%9C%A3%C2%B7%E5%BC%97%E6%9C%97%E8%A5%BF%E6%96%AF%23&xsort=hot&Refer=hotmore",
        "weibo",
    )


def test_parse_query_weibo_bu_xiang_jiao_hun_li_de_fen_zi_qian_refer_focus_lx_stopic_box_1527256388():
    verify_serp_parsing(
        "https://web.archive.org/web/20180525135308id_/http://s.weibo.com:80/weibo/%E4%B8%8D%E6%83%B3%E4%BA%A4%E5%A9%9A%E7%A4%BC%E7%9A%84%E4%BB%BD%E5%AD%90%E9%92%B1&Refer=focus_lx_STopic_box",
        "weibo",
    )


def test_parse_query_weibo_ji_huo_ma_b_1_page_2_1433297692():
    verify_serp_parsing(
        "https://web.archive.org/web/20150603021452id_/http://s.weibo.com:80/weibo/%E6%BF%80%E6%B4%BB%E7%A0%81&b=1&page=2",
        "weibo",
    )


def test_parse_query_weibo_li_wei_yi_refer_user_weibo_1517733046():
    verify_serp_parsing(
        "https://web.archive.org/web/20180204083046id_/http://s.weibo.com:80/weibo/%E6%9D%8E%E5%BE%AE%E6%BC%AA&Refer=user_weibo",
        "weibo",
    )


def test_parse_query_weibo_hun_li_li_jie_refer_stopic_box_1505917853():
    verify_serp_parsing(
        "https://web.archive.org/web/20170920143053id_/http://s.weibo.com:80/weibo/%E5%A9%9A%E7%A4%BC%E7%A4%BC%E8%8A%82&Refer=STopic_box",
        "weibo",
    )


def test_parse_query_weibo_kan_bu_jian_de_yan_pi_1409920649():
    verify_serp_parsing(
        "https://web.archive.org/web/20140905123729id_/http://s.weibo.com:80/weibo/%E7%9C%8B%E4%B8%8D%E8%A7%81%E5%BE%97%E7%9C%BC%E7%9A%AE?",
        "weibo",
    )


def test_parse_query_weibo_xiao_xiao_bin_refer_stopic_box_1518290095():
    verify_serp_parsing(
        "https://web.archive.org/web/20180210191455id_/http://s.weibo.com:80/weibo/%E5%B0%8F%E5%B0%8F%E5%BD%AC&Refer=STopic_box",
        "weibo",
    )


def test_parse_query_weibo_meng_lin_dexiao_wu_1437753277():
    verify_serp_parsing(
        "https://web.archive.org/web/20150724155437id_/http://s.weibo.com:80/weibo/%E5%AD%9F%E6%9E%97de%E5%B0%8F%E5%B1%8B?",
        "weibo",
    )


def test_parse_query_weibo_fu_cai_3dshu_ju_jia_wei_xin_xw639_2018_1555261848():
    verify_serp_parsing(
        "https://web.archive.org/web/20190414171048id_/https://s.weibo.com/weibo/%E7%A6%8F%E5%BD%A93d%E6%95%B0%E6%8D%AE%E5%8A%A0%E5%BE%AE%E2%98%85%E4%BF%A1xw639-2018%E2%80%BB",
        "weibo",
    )


def test_parse_query_weibo_quan_ye_cha_page_13_1517932436():
    verify_serp_parsing(
        "https://web.archive.org/web/20180206155356id_/http://s.weibo.com:80/weibo/%E7%8A%AC%E5%A4%9C%E5%8F%89&page=13",
        "weibo",
    )
