# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_youtube_pudding_1563068696():
    verify_serp_parsing(
        "https://web.archive.org/web/20190714014456id_/https://www.youtube.com/results?search_query=%23pudding&sp=EgQYASABSGTqAwA%253D",
        "youtube",
    )


def test_parse_query_youtube_q2_2017_arizona_west_regional_1547871680():
    verify_serp_parsing(
        "https://web.archive.org/web/20190119042120id_/https://www.youtube.com/results?search_query=Q2+2017+Arizona%20West%20Regional",
        "youtube",
    )


def test_parse_query_youtube_lataji_1563086980():
    verify_serp_parsing(
        "https://web.archive.org/web/20190714064940id_/https://www.youtube.com/results?search_query=%23LataJi&sp=CAESBhABIAEoAQ%253D%253D",
        "youtube",
    )


def test_parse_query_youtube_robloks_mip_siti_2019_1583715307():
    verify_serp_parsing(
        "https://web.archive.org/web/20200309005507id_/https://www.youtube.com/results?search_query=%D1%80%D0%BE%D0%B1%D0%BB%D0%BE%D0%BA%D1%81+%D0%BC%D0%B8%D0%BF+%D1%81%D0%B8%D1%82%D0%B8+2019&sp=SDzqAwA%253D",
        "youtube",
    )


def test_parse_query_youtube_ampatuanmassacre_1583309425():
    verify_serp_parsing(
        "https://web.archive.org/web/20200304081025id_/https://www.youtube.com/results?search_query=%23AmpatuanMassacre&app=desktop",
        "youtube",
    )


def test_parse_query_youtube_hp_probook_640_g1_razborka_1579996098():
    verify_serp_parsing(
        "https://web.archive.org/web/20200125234818id_/https://www.youtube.com/results?search_query=hp+probook+640+g1+%D1%80%D0%B0%D0%B7%D0%B1%D0%BE%D1%80%D0%BA%D0%B0",
        "youtube",
    )


def test_parse_query_youtube_razbor_shchetki_pylesosa_samsung_1584184489():
    verify_serp_parsing(
        "https://web.archive.org/web/20200314111449id_/https://www.youtube.com/results?search_query=%D1%80%D0%B0%D0%B7%D0%B1%D0%BE%D1%80+%D1%89%D0%B5%D1%82%D0%BA%D0%B8+%D0%BF%D1%8B%D0%BB%D0%B5%D1%81%D0%BE%D1%81%D0%B0+samsung",
        "youtube",
    )


def test_parse_query_youtube_literatura_6_klass_biografiia_pushkina_1595705363():
    verify_serp_parsing(
        "https://web.archive.org/web/20200725192923id_/https://www.youtube.com/results?search_query=%D0%BB%D0%B8%D1%82%D0%B5%D1%80%D0%B0%D1%82%D1%83%D1%80%D0%B0+6+%D0%BA%D0%BB%D0%B0%D1%81%D1%81+%D0%B1%D0%B8%D0%BE%D0%B3%D1%80%D0%B0%D1%84%D0%B8%D1%8F+%D0%BF%D1%83%D1%88%D0%BA%D0%B8%D0%BD%D0%B0",
        "youtube",
    )


def test_parse_query_youtube_ne_prosto_bekkhen_reaktsiia_1582514079():
    verify_serp_parsing(
        "https://web.archive.org/web/20200224031439id_/https://www.youtube.com/results?search_query=%D0%BD%D0%B5+%D0%BF%D1%80%D0%BE%D1%81%D1%82%D0%BE+%D0%B1%D1%8D%D0%BA%D1%85%D0%B5%D0%BD+%D1%80%D0%B5%D0%B0%D0%BA%D1%86%D0%B8%D1%8F",
        "youtube",
    )


def test_parse_query_youtube_prokhozhdenie_igry_madagaskar_2_chast_4_1562167916():
    verify_serp_parsing(
        "https://web.archive.org/web/20190703153156id_/https://www.youtube.com/results?search_query=%D0%BF%D1%80%D0%BE%D1%85%D0%BE%D0%B6%D0%B4%D0%B5%D0%BD%D0%B8%D0%B5+%D0%B8%D0%B3%D1%80%D1%8B+%D0%BC%D0%B0%D0%B4%D0%B0%D0%B3%D0%B0%D1%81%D0%BA%D0%B0%D1%80+2+%D1%87%D0%B0%D1%81%D1%82%D1%8C+4&sp=CAESCwgFEAQYAiAByAEB",
        "youtube",
    )


def test_parse_query_youtube_zadnii_most_moskvich_412_ustroistvo_1584150216():
    verify_serp_parsing(
        "https://web.archive.org/web/20200314014336id_/https://www.youtube.com/results?search_query=%D0%B7%D0%B0%D0%B4%D0%BD%D0%B8%D0%B9+%D0%BC%D0%BE%D1%81%D1%82+%D0%BC%D0%BE%D1%81%D0%BA%D0%B2%D0%B8%D1%87+412+%D1%83%D1%81%D1%82%D1%80%D0%BE%D0%B9%D1%81%D1%82%D0%B2%D0%BE",
        "youtube",
    )


def test_parse_query_youtube_vasilii_emelianenko_tefteli_1578285143():
    verify_serp_parsing(
        "https://web.archive.org/web/20200106043223id_/https://www.youtube.com/results?search_query=%D0%B2%D0%B0%D1%81%D0%B8%D0%BB%D0%B8%D0%B9+%D0%B5%D0%BC%D0%B5%D0%BB%D1%8C%D1%8F%D0%BD%D0%B5%D0%BD%D0%BA%D0%BE+%D1%82%D0%B5%D1%84%D1%82%D0%B5%D0%BB%D0%B8",
        "youtube",
    )


def test_parse_query_youtube_kutyaplya_1561171748():
    verify_serp_parsing(
        "https://web.archive.org/web/20190622024908id_/https://www.youtube.com/results?search_query=kutyaplya",
        "youtube",
    )


def test_parse_query_youtube_kak_sdelat_vzryv_v_cinema_4d_1578732009():
    verify_serp_parsing(
        "https://web.archive.org/web/20200111084009id_/https://www.youtube.com/results?search_query=%D0%BA%D0%B0%D0%BA+%D1%81%D0%B4%D0%B5%D0%BB%D0%B0%D1%82%D1%8C+%D0%B2%D0%B7%D1%80%D1%8B%D0%B2+%D0%B2+cinema+4d",
        "youtube",
    )


def test_parse_query_youtube_shang_yue_xian_rupu_1582390054():
    verify_serp_parsing(
        "https://web.archive.org/web/20200222164734id_/https://www.youtube.com/results?search_query=%E4%B8%8A%E8%B6%8A%E7%B7%9A+%E3%83%AB%E3%83%BC%E3%83%97",
        "youtube",
    )


def test_parse_query_youtube_pora_tiulpanov_aktery_1574991226():
    verify_serp_parsing(
        "https://web.archive.org/web/20191129013346id_/https://www.youtube.com/results?search_query=%D0%BF%D0%BE%D1%80%D0%B0+%D1%82%D1%8E%D0%BB%D1%8C%D0%BF%D0%B0%D0%BD%D0%BE%D0%B2+%D0%B0%D0%BA%D1%82%D0%B5%D1%80%D1%8B",
        "youtube",
    )


def test_parse_query_youtube_uzbekskaia_svadba_v_shymkente_1574145605():
    verify_serp_parsing(
        "https://web.archive.org/web/20191119064005id_/https://www.youtube.com/results?search_query=%D1%83%D0%B7%D0%B1%D0%B5%D0%BA%D1%81%D0%BA%D0%B0%D1%8F+%D1%81%D0%B2%D0%B0%D0%B4%D1%8C%D0%B1%D0%B0+%D0%B2+%D1%88%D1%8B%D0%BC%D0%BA%D0%B5%D0%BD%D1%82%D0%B5",
        "youtube",
    )


def test_parse_query_youtube_chto_budet_esli_sobrat_vse_rezinki_v_bully_1599555287():
    verify_serp_parsing(
        "https://web.archive.org/web/20200908085447id_/https://www.youtube.com/results?search_query=%D1%87%D1%82%D0%BE+%D0%B1%D1%83%D0%B4%D0%B5%D1%82+%D0%B5%D1%81%D0%BB%D0%B8+%D1%81%D0%BE%D0%B1%D1%80%D0%B0%D1%82%D1%8C+%D0%B2%D1%81%D0%B5+%D1%80%D0%B5%D0%B7%D0%B8%D0%BD%D0%BA%D0%B8+%D0%B2+bully",
        "youtube",
    )


def test_parse_query_youtube_kak_vybit_dushu_moba_1599057231():
    verify_serp_parsing(
        "https://web.archive.org/web/20200902143351id_/https://www.youtube.com/results?search_query=%D0%BA%D0%B0%D0%BA+%D0%B2%D1%8B%D0%B1%D0%B8%D1%82%D1%8C+%D0%B4%D1%83%D1%88%D1%83+%D0%BC%D0%BE%D0%B1%D0%B0",
        "youtube",
    )


def test_parse_query_youtube_cardistry_asmr_1577113546():
    verify_serp_parsing(
        "https://web.archive.org/web/20191223150546id_/https://www.youtube.com/results?search_query=cardistry+asmr",
        "youtube",
    )
