# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_yandex_speed_force_1535973684():
    verify_serp_parsing(
        "https://web.archive.org/web/20180903112124id_/https://yandex.ru/images/search?p=21&text=speed%20force&img_url=https%3A%2F%2Fi.ytimg.com%2Fvi%2Fy2J5Bq71emM%2Fmqdefault.jpg&pos=648&rpt=simage",
        "yandex",
    )


def test_parse_query_yandex_speed_force_1535970436():
    verify_serp_parsing(
        "https://web.archive.org/web/20180903102716id_/https://yandex.ru/images/search?p=12&text=speed%20force&img_url=https%3A%2F%2Fmedia.dayoftheshirt.com%2Fimages%2Fshirts%2F2rR4SxCzB2Yv%2Fonceuponatee_speed-force-ii_1459188765.full.png&pos=374&rpt=simage",
        "yandex",
    )


def test_parse_query_yandex_speed_force_1536100368():
    verify_serp_parsing(
        "https://web.archive.org/web/20180904223248id_/https://yandex.ru/images/search?p=16&text=speed%20force&img_url=http%3A%2F%2Fs3.birthmoviesdeath.com%2Fimages%2Fmade%2FFFSF4_1200_1220_81_s.jpg&pos=502&rpt=simage",
        "yandex",
    )


def test_parse_query_yandex_spirited_away_animated_film_2001_1524478207():
    verify_serp_parsing(
        "https://web.archive.org/web/20180423101007id_/https://yandex.ru/video/search?text=spirited%20away%20animated%20film%202001&source=recommendations&path=main&personal=false&autoplay=1",
        "yandex",
    )


def test_parse_query_yandex_speed_force_1536042339():
    verify_serp_parsing(
        "https://web.archive.org/web/20180904062539id_/https://yandex.ru/images/search?p=2&text=speed%20force&img_url=https%3A%2F%2Fandroidapplications.ru%2Fuploads%2Fposts%2F2017-04%2F1492531591_speed_force_race_-_gonki-6.jpg&pos=82&rpt=simage",
        "yandex",
    )


def test_parse_query_yandex_danses_tv_periodic_1534841786():
    verify_serp_parsing(
        "https://web.archive.org/web/20180821085626id_/https://yandex.ru/video/search?text=danses%20tv%20periodic&source=recommendations&path=main&within=9&personal=false",
        "yandex",
    )


def test_parse_query_yandex_virat_swaroop_1523992633():
    verify_serp_parsing(
        "https://web.archive.org/web/20180417191713id_/https://yandex.ru/images/search?text=virat%20swaroop",
        "yandex",
    )


def test_parse_query_yandex_niusha_1515577404():
    verify_serp_parsing(
        "https://web.archive.org/web/20180110094324id_/https://yandex.ru/video/search?text=%D0%9D%D1%8E%D1%88%D0%B0&source=oo&entref=0oCgpydXcyNDk5MjQzEg9ydXczOTUwNDctYXNzb2MYAt5s7-k&parent-reqid=1515552693812954-1072433413594552848811520-vla1-2341-V",
        "yandex",
    )


def test_parse_query_yandex_speed_force_1535955246():
    verify_serp_parsing(
        "https://web.archive.org/web/20180903061406id_/https://yandex.ru/images/search?p=4&text=speed%20force&img_url=https%3A%2F%2Fwww.old-games.ru%2Fforum%2Fattachments%2Faveg-by_z_2016_01_04_20_06_43_66ae17e6-jpg.98982%2F&pos=132&uinfo=sw-1280-sh-800-ww-1280-wh-649-pd-1-wp-16x10_1280x800&rpt=simage",
        "yandex",
    )


def test_parse_query_yandex_speed_force_1535895408():
    verify_serp_parsing(
        "https://web.archive.org/web/20180902133648id_/https://yandex.ru/images/search?p=15&text=speed%20force&img_url=https%3A%2F%2Fget.wallhere.com%2Fphoto%2Fillustration-anime-death-God-Flash-comics-ART-color-comic-book-fiction-5714.jpg&pos=454&rpt=simage",
        "yandex",
    )
