# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_bing_uscis_forms_400_1486690408():
    verify_serp_parsing(
        "https://web.archive.org/web/20170210013328id_/http://www.bing.com/images/search?q=USCIS+Forms+400&FORM=RESTAB",
        "bing",
    )


def test_parse_query_bing_regional_asia_taiwan_localities_taichung_city_1580952978():
    verify_serp_parsing(
        "https://web.archive.org/web/20200206013618id_/https://www.bing.com/search?q=Regional+Asia+Taiwan+Localities+Taichung+City",
        "bing",
    )


def test_parse_query_bing_intel_i7_chip_1656625238():
    verify_serp_parsing(
        "https://web.archive.org/web/20220630214038id_/https://www.bing.com/search?q=intel+i7+chip&lvl=1&FORM=PMETIS&filters=ans%3A%22cvns%22+level%3A%220%22+mcid%3A%229363152adf5f441aa0dd1d28d3cf21f2%22&idx=0",
        "bing",
    )


def test_parse_query_bing_rpg_title_screen_1656104004():
    verify_serp_parsing(
        "https://web.archive.org/web/20220624205324id_/https://www.bing.com/images/search?q=RPG+Title+Screen&FORM=IRMHRS",
        "bing",
    )


def test_parse_query_bing_win10_iso_xia_zai_1580349240():
    verify_serp_parsing(
        "https://web.archive.org/web/20200130015400id_/https://www.bing.com/search?q=win10+iso+%E4%B8%8B%E8%BD%BD&filters=ex1%3A%22ez1%22&qpvt=win10+iso+%E4%B8%8B%E8%BD%BD",
        "bing",
    )


def test_parse_query_bing_great_blue_heron_sound_1660552923():
    verify_serp_parsing(
        "https://web.archive.org/web/20220815084203id_/https://www.bing.com/search?q=great+blue+heron+sound&FORM=QSRE1",
        "bing",
    )


def test_parse_query_bing_wonder_kids_beginning_1652132287():
    verify_serp_parsing(
        "https://web.archive.org/web/20220509213807id_/https://www.bing.com/search?q=wonder+kids+beginning&pc=0TRO&ptag=C1N6612A70619013F5&form=CONBNT&conlogo=CT3210127",
        "bing",
    )


def test_parse_query_bing_mesozoic_wikipedia_1643229373():
    verify_serp_parsing(
        "https://web.archive.org/web/20220126203613id_/https://www.bing.com/search?q=Mesozoic+wikipedia&form=WIKIRE",
        "bing",
    )


def test_parse_query_bing_kumolife_1388896361():
    verify_serp_parsing(
        "https://web.archive.org/web/20140105043241id_/http://www.bing.com/search?q=kumolife&form=MSSRPD",
        "bing",
    )


def test_parse_query_bing_florence_caillon_bandcamp_1647897680():
    verify_serp_parsing(
        "https://web.archive.org/web/20220321212120id_/https://www.bing.com/search?q=Florence+Caillon+bandcamp&qs=n&form=QBRE&=Search+%7B0%7D+for+%7B1%7D&=Search+work+for+%7B0%7D&=%25eManage+Your+Search+History%25E&sp=-1&pq=florence+caillon+bandcamp&sc=1-25&sk=&cvid=E5A3CCFC449440CABF3E217E535C5DD6",
        "bing",
    )


def test_parse_query_bing_common_use_facilities_1643636012():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131133332id_/https://www.bing.com/search?q=Common+use+facilities",
        "bing",
    )


def test_parse_query_bing_corner_app_1618998889():
    verify_serp_parsing(
        "https://web.archive.org/web/20210421095449id_/https://www.bing.com/search?q=Corner+App",
        "bing",
    )


def test_parse_query_bing_blockbench_github_1652298697():
    verify_serp_parsing(
        "https://web.archive.org/web/20220511195137id_/https://www.bing.com/search?q=blockbench+github&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_dash_investment_foundation_1644415217():
    verify_serp_parsing(
        "https://web.archive.org/web/20220209140017id_/https://www.bing.com/search?q=Dash+Investment+Foundation",
        "bing",
    )


def test_parse_query_bing_mehmet_oz_florida_hunting_license_1657728564():
    verify_serp_parsing(
        "https://web.archive.org/web/20220713160924id_/http://www.bing.com/search?q=Mehmet+Oz+Florida+hunting+license&FORM=HDRSC1",
        "bing",
    )


def test_parse_query_bing_agent_077_mission_bloody_mary_movie_1593376539():
    verify_serp_parsing(
        "https://web.archive.org/web/20200628203539id_/https://www.bing.com/search?q=agent+077+mission+bloody+mary+movie&FORM=HDRSC1",
        "bing",
    )


def test_parse_query_bing_connecticut_covid_deaths_1628019384():
    verify_serp_parsing(
        "https://web.archive.org/web/20210803193624id_/https://www.bing.com/search?q=Connecticut+covid+deaths",
        "bing",
    )


def test_parse_query_bing_sungard_1555022695():
    verify_serp_parsing(
        "https://web.archive.org/web/20190411224455id_/https://www.bing.com/search?q=SunGard&filters=ufn%3a%22SunGard%22+sid%3a%22c066bda2-94db-d8c0-eb7a-2ddf1fb005e6%22&FORM=SNAPST",
        "bing",
    )


def test_parse_query_bing_limbpower_1640025328():
    verify_serp_parsing(
        "https://web.archive.org/web/20211220183528id_/https://www.bing.com/search?q=LimbPower",
        "bing",
    )


def test_parse_query_bing_clobetasol_without_prescription_1615178898():
    verify_serp_parsing(
        "https://web.archive.org/web/20210308044818id_/http://www.bing.com/search?q=clobetasol+without+prescription",
        "bing",
    )


def test_parse_query_bing_classement_de_la_premier_league_1658725630():
    verify_serp_parsing(
        "https://web.archive.org/web/20220725050710id_/https://www.bing.com/search?q=classement+de+la+premier+league&FORM=RS1208",
        "bing",
    )


def test_parse_query_bing_crimson_coward_1640789839():
    verify_serp_parsing(
        "https://web.archive.org/web/20211229145719id_/https://www.bing.com/search?q=Crimson+Coward",
        "bing",
    )


def test_parse_query_bing_harukazewakaba0_1643181401():
    verify_serp_parsing(
        "https://web.archive.org/web/20220126071641id_/https://www.bing.com/search?q=harukazewakaba0&FORM=HDRSC1",
        "bing",
    )


def test_parse_query_bing_nexus_mods_manager_1662582175():
    verify_serp_parsing(
        "https://web.archive.org/web/20220907202255id_/https://www.bing.com/search?q=nexus+mods+manager&FORM=QSRE4",
        "bing",
    )


def test_parse_query_bing_shang_chi_film_1563662560():
    verify_serp_parsing(
        "https://web.archive.org/web/20190720224240id_/https://www.bing.com/search?q=Shang-Chi+film&filters=ufn%3a%22Shang-Chi+film%22+sid%3a%2233883806-0a4a-6aae-5598-51112dd2a9f4%22+catguid%3a%22ca394de6-2ef0-65dd-291d-1b2c098e50c3_cfb02057%22+segment%3a%22generic.carousel%22&FORM=SNAPST",
        "bing",
    )


def test_parse_query_bing_obama_speech_1274497739():
    verify_serp_parsing(
        "https://web.archive.org/web/20100522030859id_/http://www.bing.com:80/search?q=Obama+Speech&FORM=QSRE4",
        "bing",
    )


def test_parse_query_bing_elon_musk_tesla_stock_drop_1656685094():
    verify_serp_parsing(
        "https://web.archive.org/web/20220701141814id_/https://www.bing.com/search?q=elon+musk+tesla+stock+drop&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_wikipedia_rock_macabre_1603539954():
    verify_serp_parsing(
        "https://web.archive.org/web/20201024114554id_/https://www.bing.com/search?q=-wikipedia+%22Rock+macabre%22",
        "bing",
    )


def test_parse_query_bing_dan_robitzski_1660531082():
    verify_serp_parsing(
        "https://web.archive.org/web/20220815023802id_/https://www.bing.com/search?q=Dan+Robitzski",
        "bing",
    )


def test_parse_query_bing_arab_suck_and_fuck_bouchra_1365405319():
    verify_serp_parsing(
        "https://web.archive.org/web/20130408071519id_/http://www.bing.com/search?q=arab+suck+and+fuck+bouchra&qs=ns&form=QBLH",
        "bing",
    )


def test_parse_query_bing_wikipedia_orb_univers_de_fiction_1643880033():
    verify_serp_parsing(
        "https://web.archive.org/web/20220203092033id_/https://www.bing.com/search?q=-wikipedia+%22Orb+(univers+de+fiction)%22",
        "bing",
    )


def test_parse_query_bing_vintage_pittsburgh_steelers_steel_curtain_1497160668():
    verify_serp_parsing(
        "https://web.archive.org/web/20170611055748id_/https://www.bing.com/images/search?q=Vintage+Pittsburgh+Steelers+Steel+Curtain&FORM=RESTAB",
        "bing",
    )


def test_parse_query_bing_team_liquid_teams_1652030641():
    verify_serp_parsing(
        "https://web.archive.org/web/20220508172401id_/https://www.bing.com/search?FORM=SNAPST&q=Team+Liquid+teams&filters=ufn%3A%22team+liquid+apex+legends%22+sid%3A%22fb8246be-afdd-9186-3fb4-757eae77b365%22+catguid%3A%224cfd7f5f-fec1-e5d7-15c6-9c6539ed366d_6848f442%22+segment%3A%22generic.carousel%22+gsexp%3A%224cfd7f5f-fec1-e5d7-15c6-9c6539ed366d_bXNvL3Nwb3J0cy5sZWFndWUudGVhbXN8VHJ1ZXxtc28vc3BvcnRzLmxlYWd1ZV9wYXJ0aWNpcGF0aW9uLnRlYW18VHJ1ZQ..%22",
        "bing",
    )


def test_parse_query_bing_european_cannibalism_1591185526():
    verify_serp_parsing(
        "https://web.archive.org/web/20200603115846id_/https://www.bing.com/search?q=european+cannibalism&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_customer_service_phone_number_for_hp_printer_1662986585():
    verify_serp_parsing(
        "https://web.archive.org/web/20220912124305id_/https://www.bing.com/search?q=customer+service+phone+number+for+hp+printer&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_mighty_music_1578065758():
    verify_serp_parsing(
        "https://web.archive.org/web/20200103153558id_/https://www.bing.com/images/search?q=Mighty+Music&FORM=HDRSC2",
        "bing",
    )


def test_parse_query_bing_christian_r_ntizimira_1607730426():
    verify_serp_parsing(
        "https://web.archive.org/web/20201211234706id_/https://www.bing.com/search?q=Christian+R.+Ntizimira",
        "bing",
    )


def test_parse_query_bing_libyan_syrian_union_1643642965():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131152925id_/https://www.bing.com/search?q=Libyan+Syrian+Union",
        "bing",
    )


def test_parse_query_bing_1968_cougar_on_craigslist_1480218715():
    verify_serp_parsing(
        "https://web.archive.org/web/20161127035155id_/http://www.bing.com/search?q=1968+cougar+on+craigslist&form=QBRE",
        "bing",
    )


def test_parse_query_bing_explore_with_us_youtube_emma_1651605205():
    verify_serp_parsing(
        "https://web.archive.org/web/20220503191325id_/https://www.bing.com/search?q=explore+with+us+youtube+emma&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_clay_andrews_1649253287():
    verify_serp_parsing(
        "https://web.archive.org/web/20220406135447id_/https://www.bing.com/search?q=Clay+Andrews",
        "bing",
    )


def test_parse_query_bing_kutuklui_affair_1643643819():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131154339id_/https://www.bing.com/search?q=Kutuklui+Affair",
        "bing",
    )


def test_parse_query_bing_the_clavarioid_fungi_of_new_zealand_ron_petersen_1556393373():
    verify_serp_parsing(
        "https://web.archive.org/web/20190427192933id_/https://www.bing.com/search?q=The+clavarioid+fungi+of+New+Zealand+Ron+Petersen&filters=ufn%3a%22The+clavarioid+fungi+of+New+Zealand+Ron+Petersen%22+sid%3a%220b30c0ac-f55d-3966-3df7-6c37ffc7e507%22+catguid%3a%229d080d55-a2a0-4c60-debe-b536d8a0aa82_c0bcbbc4%22+segment%3a%22generic.carousel%22&FORM=SNAPST",
        "bing",
    )


def test_parse_query_bing_wikipedia_port_de_gennevilliers_metro_de_paris_1604443017():
    verify_serp_parsing(
        "https://web.archive.org/web/20201103223657id_/https://www.bing.com/search?q=-wikipedia+%22Port+de+Gennevilliers+(m%C3%A9tro+de+Paris)%22",
        "bing",
    )


def test_parse_query_bing_wikipedia_vesuvius_1641311740():
    verify_serp_parsing(
        "https://web.archive.org/web/20220104155540id_/https://www.bing.com/search?q=-wikipedia+%22Vesuvius%22",
        "bing",
    )


def test_parse_query_bing_countercyclical_fiscal_policy_1643622693():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131095133id_/https://www.bing.com/search?q=Countercyclical+fiscal+policy",
        "bing",
    )


def test_parse_query_bing_herzlich_willkommen_unterbindet_den_storeinfluss_bei_psychosen_1650332555():
    verify_serp_parsing(
        "https://web.archive.org/web/20220419014235id_/https://www.bing.com/search?q=%22Herzlich+willkommen+!%22+unterbindet+den+St%C3%B6reinfluss+bei+Psychosen&go=Suche&qs=ds&form=QBRE",
        "bing",
    )


def test_parse_query_bing_limited_range_icbm_1643649846():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131172406id_/https://www.bing.com/search?q=Limited+Range+ICBM",
        "bing",
    )


def test_parse_query_bing_lake_wappapello_state_wildlife_area_1643615402():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131075002id_/https://www.bing.com/search?q=Lake+Wappapello+State+Wildlife+Area",
        "bing",
    )


def test_parse_query_bing_sweden_riots_1618569435():
    verify_serp_parsing(
        "https://web.archive.org/web/20210416103715id_/https://www.bing.com/search?q=Sweden+Riots&FORM=HDRSC1",
        "bing",
    )


def test_parse_query_bing_dataquantum_com_vancouver_hosting_1375879464():
    verify_serp_parsing(
        "https://web.archive.org/web/20130807124424id_/http://www.bing.com/search?q=%64%61%74%61%71%75%61%6e%74%75%6d%2e%63%6f%6d%2b%56%61%6e%63%6f%75%76%65%72%2b%68%6f%73%74%69%6e%67",
        "bing",
    )


def test_parse_query_bing_cody_machan_facebook_1594008363():
    verify_serp_parsing(
        "https://web.archive.org/web/20200706040603id_/https://www.bing.com/search?q=cody+machan+facebook&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_allovercr_1423275634():
    verify_serp_parsing(
        "https://web.archive.org/web/20150207022034id_/http://www.bing.com/search?q=allovercr&go=Enviar+consulta&qs=ds&form=QBRE",
        "bing",
    )


def test_parse_query_bing_aldershot_news_1629564105():
    verify_serp_parsing(
        "https://web.archive.org/web/20210821164145id_/https://www.bing.com/search?q=aldershot+news&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_eero_pro_mesh_wifi_system_1659437763():
    verify_serp_parsing(
        "https://web.archive.org/web/20220802105603id_/https://www.bing.com/search?q=eero+pro+mesh+wifi+system&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_computers_software_presentation_1488623366():
    verify_serp_parsing(
        "https://web.archive.org/web/20170304102926id_/https://www.bing.com/search?q=Computers+Software+Presentation",
        "bing",
    )


def test_parse_query_bing_1137ce_1639788231():
    verify_serp_parsing(
        "https://web.archive.org/web/20211218004351id_/http://www.bing.com/search?q=1137CE",
        "bing",
    )


def test_parse_query_bing_wikipedia_sider_tribu_1593501017():
    verify_serp_parsing(
        "https://web.archive.org/web/20200630071017id_/https://www.bing.com/search?q=-wikipedia+%22Sider+(tribu)%22",
        "bing",
    )


def test_parse_query_bing_100_9_classic_country_radio_station_alaska_1660338459():
    verify_serp_parsing(
        "https://web.archive.org/web/20220812210739id_/https://www.bing.com/search?q=100.9+classic+country+radio+station+alaska&FORM=QSRE6",
        "bing",
    )


def test_parse_query_bing_wikipedia_privatbrauerei_hoepfner_1620534005():
    verify_serp_parsing(
        "https://web.archive.org/web/20210509042005id_/https://www.bing.com/search?q=-wikipedia+%22Privatbrauerei+Hoepfner%22",
        "bing",
    )
