# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_naver_11548566_973003263():
    verify_serp_parsing(
        "https://web.archive.org/web/20001031144103id_/http://search.naver.com:80/search.naver?where=web&type=3&query=11548566",
        "naver",
    )


def test_parse_query_naver_monteria_montheria_bunyupoteu_jeongitipoteu_jeongijujeonja_bunyupoteugi_1200ml_1200mlpingkeu_hugi_1640713881():
    verify_serp_parsing(
        "https://web.archive.org/web/20211228175121id_/https://search.naver.com/search.naver?query=%EB%AA%AC%ED%85%8C%EB%A6%AC%EC%95%84%20Montheria%20%EB%B6%84%EC%9C%A0%ED%8F%AC%ED%8A%B8%20%EC%A0%84%EA%B8%B0%ED%8B%B0%ED%8F%AC%ED%8A%B8%20%EC%A0%84%EA%B8%B0%EC%A3%BC%EC%A0%84%EC%9E%90%20%EB%B6%84%EC%9C%A0%ED%8F%AC%ED%8A%B8%EA%B8%B0%201200ML,%201200ml%ED%95%91%ED%81%AC+%ED%9B%84%EA%B8%B0",
        "naver",
    )


def test_parse_query_naver_heolkeu_dari_gajin_namja_1397449417():
    verify_serp_parsing(
        "https://web.archive.org/web/20140414042337id_/http://search.naver.com/search.naver?where=nexearch&query=%ED%97%90%ED%81%AC+%EB%8B%A4%EB%A6%AC+%EA%B0%80%EC%A7%84+%EB%82%A8%EC%9E%90&ie=utf8&sm=nws_htk",
        "naver",
    )


def test_parse_query_naver_10559239_974530320():
    verify_serp_parsing(
        "https://web.archive.org/web/20001118065200id_/http://search.naver.com:80/search.naver?where=web&type=3&query=10559239",
        "naver",
    )


def test_parse_query_naver_junggangosagongbu_1627424756():
    verify_serp_parsing(
        "https://web.archive.org/web/20210727222556id_/https://search.naver.com/search.naver?where=view&sm=tab_viw.all&query=%EC%A4%91%EA%B0%84%EA%B3%A0%EC%82%AC%EA%B3%B5%EB%B6%80",
        "naver",
    )


def test_parse_query_naver_dpsxmfl_1632292908():
    verify_serp_parsing(
        "https://web.archive.org/web/20210922064148id_/https://search.naver.com/search.naver?where=nexearch&query=dpsxmfl&x=31&y=5&frm=t1",
        "naver",
    )


def test_parse_query_naver_sejongmunhwahoegwan_daegeugjang_1652993423():
    verify_serp_parsing(
        "https://web.archive.org/web/20220519205023id_/https://search.naver.com/search.naver?where=image&sm=tab_jum&query=%EC%84%B8%EC%A2%85%EB%AC%B8%ED%99%94%ED%9A%8C%EA%B4%80+%EB%8C%80%EA%B7%B9%EC%9E%A5",
        "naver",
    )


def test_parse_query_naver_geobugseon_1439284748():
    verify_serp_parsing(
        "https://web.archive.org/web/20150811091908id_/http://search.naver.com/search.naver?where=nexearch&query=%EA%B1%B0%EB%B6%81%EC%84%A0&sm=top_lve&ie=utf8",
        "naver",
    )


def test_parse_query_naver_z_974687640():
    verify_serp_parsing(
        "https://web.archive.org/web/20001120023400id_/http://search.naver.com:80/search.naver?where=nexearch&query=%C0%E5%BF%DC+%B9%DF%B8%C5%BC%D2",
        "naver",
    )


def test_parse_query_naver_t_1047137339():
    verify_serp_parsing(
        "https://web.archive.org/web/20030308152859id_/http://search.naver.com:80/search.naver?where=nexearch&query=%bd%ba%c6%ae%b8%b3%bc%ee%ba%b8%bf%a9%c1%e0",
        "naver",
    )
