# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_linkedin_vizthink_1229875736():
    verify_serp_parsing(
        "https://web.archive.org/web/20081221160856id_/http://www.linkedin.com:80/search?search=&sortCriteria=3&keywords=VizThink&goback=%2Esrp_1_1211730310191_in",
        "linkedin",
    )


def test_parse_query_linkedin_parent_information_center_of_nj_https_www_linkedin_com_feed_1537815970():
    verify_serp_parsing(
        "https://web.archive.org/web/20180924190610id_/https://www.linkedin.com/search/results/all/?keywords=Parent%20Information%20Center%20of%20NJ/../https://www.linkedin.com/feed/",
        "linkedin",
    )


def test_parse_query_linkedin_g_d_goenka_international_school_surat_wisdom_valley_campus_nr_anuvrat_dwar_new_city_light_road_rcc_canal_road_bar_surat_gujrat_1568400864():
    verify_serp_parsing(
        "https://web.archive.org/web/20190913185424id_/https://www.linkedin.com/search/results/all/?keywords=G.%20D.%20Goenka%20International%20School%20Surat%20Wisdom%20Valley%20campus,%20Nr.%20Anuvrat%20Dwar,%20New%20City%20Light%20Road,%20RCC%20Canal%20Road,%20Bar%20Surat%20GUJRAT",
        "linkedin",
    )


def test_parse_query_linkedin_test_1563279735():
    verify_serp_parsing(
        "https://web.archive.org/web/20190716122215id_/https://www.linkedin.com/search/results/content/?keywords=test&origin=test%20UNION%20ALL%20SELECT%20NULL%2CNULL%2CNULL--%20FPED&",
        "linkedin",
    )


def test_parse_query_linkedin_cryptocurrencies_1556702372():
    verify_serp_parsing(
        "https://web.archive.org/web/20190501091932id_/https://www.linkedin.com/search/results/content/?keywords=%23cryptocurrencies&origin=GLOBAL_SEARCH_HEADER",
        "linkedin",
    )


def test_parse_query_linkedin_james_margolin_fbi_1571382052():
    verify_serp_parsing(
        "https://web.archive.org/web/20191018070052id_/https://www.linkedin.com/search/results/all/?keywords=james%20margolin%20fbi&origin=GLOBAL_SEARCH_HEADER",
        "linkedin",
    )


def test_parse_query_linkedin_parent_information_center_of_nj_https_www_linkedin_com_search_results_all_keywords_parent_information_center_of_nj_1537815969():
    verify_serp_parsing(
        "https://web.archive.org/web/20180924190609id_/https://www.linkedin.com/search/results/all/?keywords=Parent%20Information%20Center%20of%20NJ/../https://www.linkedin.com/search/results/all/?keywords=Parent%20Information%20Center%20of%20NJ",
        "linkedin",
    )
