# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_qwant_administrateur_general_du_cnam_1619206522():
    verify_serp_parsing(
        "https://web.archive.org/web/20210423193522id_/https://www.qwant.com/?q=%22Administrateur+g%C3%A9n%C3%A9ral+du+Cnam%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_great_falls_gun_club_1637348184():
    verify_serp_parsing(
        "https://web.archive.org/web/20211119185624id_/https://www.qwant.com/?q=great+falls+gun+club&client=ext-firefox-sb&t=web",
        "qwant",
    )


def test_parse_query_qwant_rosa_linux_1664389965():
    verify_serp_parsing(
        "https://web.archive.org/web/20220928183245id_/https://www.qwant.com/?q=%22ROSA+Linux%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_the_owl_club_1666374443():
    verify_serp_parsing(
        "https://web.archive.org/web/20221021174723id_/https://www.qwant.com/?q=the+owl+club&client=ext-firefox-sb&t=web",
        "qwant",
    )


def test_parse_query_qwant_journee_nationale_du_drapeau_gabonais_1628405454():
    verify_serp_parsing(
        "https://web.archive.org/web/20210808065054id_/https://www.qwant.com/?q=%22Journ%C3%A9e+nationale+du+drapeau+gabonais%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_drapeau_canadien_1615473541():
    verify_serp_parsing(
        "https://web.archive.org/web/20210311143901id_/https://www.qwant.com/?q=drapeau+canadien&client=brz-brave",
        "qwant",
    )


def test_parse_query_qwant_hovelhof_1461470750():
    verify_serp_parsing(
        "https://web.archive.org/web/20160424040550id_/https://www.qwant.com/?q=h%C3%B6velhof",
        "qwant",
    )


def test_parse_query_qwant_eric_singer_drums_1621083357():
    verify_serp_parsing(
        "https://web.archive.org/web/20210515125557id_/https://www.qwant.com/?q=eric+singer+drums&t=all",
        "qwant",
    )


def test_parse_query_qwant_obs_keyframe_interval_1657322209():
    verify_serp_parsing(
        "https://web.archive.org/web/20220708231649id_/https://www.qwant.com/?q=obs+keyframe+interval&client=ext-firefox-sb&t=web",
        "qwant",
    )


def test_parse_query_qwant_celine_de_roany_1640557696():
    verify_serp_parsing(
        "https://web.archive.org/web/20211226222816id_/https://www.qwant.com/?q=%22C%C3%A9line+de+Roany%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_festival_corazon_latino_1644332358():
    verify_serp_parsing(
        "https://web.archive.org/web/20220208145918id_/https://www.qwant.com/?q=%22Festival+Coraz%C3%B3n+latino%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_trouve_arc_bf4_1625314405():
    verify_serp_parsing(
        "https://web.archive.org/web/20210703121325id_/https://www.qwant.com/?q=trouv%C3%A9+arc+bf4&client=brz-brave",
        "qwant",
    )


def test_parse_query_qwant_dr_heim_tampa_1631748962():
    verify_serp_parsing(
        "https://web.archive.org/web/20210915233602id_/https://www.qwant.com/?q=dr+heim+tampa&t=all",
        "qwant",
    )


def test_parse_query_qwant_sacred_age_odysseria_1652523638():
    verify_serp_parsing(
        "https://web.archive.org/web/20220514102038id_/https://www.qwant.com/?q=%2BSacred+Age+Odysseria&client=ext-firefox-sb&t=web",
        "qwant",
    )


def test_parse_query_qwant_musique_folklorique_bretonne_1631820741():
    verify_serp_parsing(
        "https://web.archive.org/web/20210916193221id_/https://www.qwant.com/?q=musique+folklorique+bretonne&t=all",
        "qwant",
    )


def test_parse_query_qwant_initialiser_debat_dadmissibilite_1645273237():
    verify_serp_parsing(
        "https://web.archive.org/web/20220219122037id_/https://www.qwant.com/?q=%22Initialiser+D%C3%A9bat+d%26%2339%3Badmissibilit%C3%A9%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_geographie_de_la_france_1620931197():
    verify_serp_parsing(
        "https://web.archive.org/web/20210513183957id_/https://www.qwant.com/?q=geographie+de+la+france&t=all",
        "qwant",
    )


def test_parse_query_qwant_anna_sottilotta_1630417705():
    verify_serp_parsing(
        "https://web.archive.org/web/20210831134825id_/https://www.qwant.com/?q=anna+sottilotta&t=all",
        "qwant",
    )


def test_parse_query_qwant_metal_slug_foo_1624572900():
    verify_serp_parsing(
        "https://web.archive.org/web/20210624221500id_/https://www.qwant.com/?q=metal+slug+foo&client=brz-brave",
        "qwant",
    )


def test_parse_query_qwant_another_word_for_less_likely_1641721403():
    verify_serp_parsing(
        "https://web.archive.org/web/20220109094323id_/https://www.qwant.com/?q=another+word+for+less+likely&t=all",
        "qwant",
    )


def test_parse_query_qwant_rmvmn_1619293679():
    verify_serp_parsing(
        "https://web.archive.org/web/20210424194759id_/https://www.qwant.com/?q=%22RMVMN%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_unification_album_1626264528():
    verify_serp_parsing(
        "https://web.archive.org/web/20210714120848id_/https://www.qwant.com/?q=%22Unification+(album)%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_rob_diamond_movies_1626693763():
    verify_serp_parsing(
        "https://web.archive.org/web/20210719112243id_/https://www.qwant.com/?q=rob+diamond+movies&t=all",
        "qwant",
    )


def test_parse_query_qwant_code_9_1661507082():
    verify_serp_parsing(
        "https://web.archive.org/web/20220826094442id_/https://www.qwant.com/?q=%22Code+9%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_bluestacks_keyboard_not_working_1637463746():
    verify_serp_parsing(
        "https://web.archive.org/web/20211121030226id_/https://www.qwant.com/?q=bluestacks+keyboard+not+working&client=brz-brave&t=web",
        "qwant",
    )


def test_parse_query_qwant_jesus_mendez_facebook_1642962807():
    verify_serp_parsing(
        "https://web.archive.org/web/20220123183327id_/https://www.qwant.com/?q=jesus+mendez+facebook&t=all",
        "qwant",
    )


def test_parse_query_qwant_marcel_caya_1628794563():
    verify_serp_parsing(
        "https://web.archive.org/web/20210812185603id_/https://www.qwant.com/?q=%22Marcel+Caya%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_david_shepard_restaurateur_de_film_1595246740():
    verify_serp_parsing(
        "https://web.archive.org/web/20200720120540id_/https://www.qwant.com/?q=%22David+Shepard+(restaurateur+de+film)%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_phantasialand_1461344566():
    verify_serp_parsing(
        "https://web.archive.org/web/20160422170246id_/https://www.qwant.com/?q=phantasialand",
        "qwant",
    )


def test_parse_query_qwant_attaque_a_tunis_1433356632():
    verify_serp_parsing(
        "https://web.archive.org/web/20150603183712id_/https://www.qwant.com/?q=Attaque+%C3%A0+Tunis&source=news",
        "qwant",
    )


def test_parse_query_qwant_neonazis_en_france_1663085614():
    verify_serp_parsing(
        "https://web.archive.org/web/20220913161334id_/https://www.qwant.com/?client=brz-moz&t=videos&q=n%C3%A9onazis+en+France&o=0%3AMJrfVZ7PGdc",
        "qwant",
    )


def test_parse_query_qwant_victoria_zdrok_1632510384():
    verify_serp_parsing(
        "https://web.archive.org/web/20210924190624id_/https://www.qwant.com/?q=%22Victoria+Zdrok%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_ouat_once_upon_a_train_1643380520():
    verify_serp_parsing(
        "https://web.archive.org/web/20220128143520id_/https://www.qwant.com/?q=%22OUAT+-+Once+Upon+A+Train%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_skerdi_dervishaj_1635917093():
    verify_serp_parsing(
        "https://web.archive.org/web/20211103052453id_/https://www.qwant.com/?q=%22Skerdi+Dervishaj%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_allades_1631959376():
    verify_serp_parsing(
        "https://web.archive.org/web/20210918100256id_/https://www.qwant.com/?q=%22Allad%C3%A8s%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_world_deutsch_regional_europa_deutschland_baden_wurttemberg_landkreise_heilbronn_stadte_und_gemeinde_1626329085():
    verify_serp_parsing(
        "https://web.archive.org/web/20210715060445id_/https://www.qwant.com/?q=World+Deutsch+Regional+Europa+Deutschland+Baden-W%C3%BCrttemberg+Landkreise+Heilbronn+St%C3%A4dte+und+Gemeinden+W%C3%BCstenrot",
        "qwant",
    )


def test_parse_query_qwant_toddlercon_1579361594():
    verify_serp_parsing(
        "https://web.archive.org/web/20200118153314id_/https://www.qwant.com/?client=brz-vivaldi&q=Toddlercon",
        "qwant",
    )


def test_parse_query_qwant_guerre_froide_1654846351():
    verify_serp_parsing(
        "https://web.archive.org/web/20220610073231id_/https://www.qwant.com/?l=fr&t=videos&q=guerre+froide",
        "qwant",
    )


def test_parse_query_qwant_lombocruralgie_francais_1656441384():
    verify_serp_parsing(
        "https://web.archive.org/web/20220628183624id_/https://www.qwant.com/?q=lombocruralgie+francais&t=all",
        "qwant",
    )


def test_parse_query_qwant_volt_bulgarie_1628499772():
    verify_serp_parsing(
        "https://web.archive.org/web/20210809090252id_/https://www.qwant.com/?q=%22Volt+Bulgarie%22&t=all",
        "qwant",
    )


def test_parse_query_qwant_what_is_beowulf_about_summary_1659304409():
    verify_serp_parsing(
        "https://web.archive.org/web/20220731215329id_/https://www.qwant.com/?q=what+is+beowulf+about+summary&client=ext-chrome-sb&t=web",
        "qwant",
    )


def test_parse_query_qwant_tv_horror_movies_chart_1667140806():
    verify_serp_parsing(
        "https://web.archive.org/web/20221030144006id_/https://www.qwant.com/?q=%2Ftv%2F+horror+movies+chart&client=opensearch&t=web",
        "qwant",
    )


def test_parse_query_qwant_steam_ubuntu_wiki_1592725715():
    verify_serp_parsing(
        "https://web.archive.org/web/20200621074835id_/https://www.qwant.com/?client=brz-moz&q=Steam+ubuntu+wiki",
        "qwant",
    )


def test_parse_query_qwant_que_tal_magazine_1643474954():
    verify_serp_parsing(
        "https://web.archive.org/web/20220129164914id_/https://www.qwant.com/?q=que+tal+magazine&t=all",
        "qwant",
    )


def test_parse_query_qwant_sporting_stadium_1640362241():
    verify_serp_parsing(
        "https://web.archive.org/web/20211224161041id_/https://www.qwant.com/?q=sporting+stadium&t=all",
        "qwant",
    )


def test_parse_query_qwant_danse_1460250714():
    verify_serp_parsing(
        "https://web.archive.org/web/20160410011154id_/https://www.qwant.com/?q=danse",
        "qwant",
    )


def test_parse_query_qwant_lemke_software_gmbh_1625227146():
    verify_serp_parsing(
        "https://web.archive.org/web/20210702115906id_/https://www.qwant.com/?q=lemke+software+gmbh&t=all",
        "qwant",
    )


def test_parse_query_qwant_dr_michael_valliere_1653406352():
    verify_serp_parsing(
        "https://web.archive.org/web/20220524153232id_/https://www.qwant.com/?q=dr+michael+valliere&t=all",
        "qwant",
    )


def test_parse_query_qwant_fredrik_lundberg_1665847606():
    verify_serp_parsing(
        "https://web.archive.org/web/20221015152646id_/https://www.qwant.com/?q=fredrik+lundberg&client=opensearch&t=web",
        "qwant",
    )


def test_parse_query_qwant_i_squared_capital_linkedin_1653657436():
    verify_serp_parsing(
        "https://web.archive.org/web/20220527131716id_/https://www.qwant.com/?q=i+squared+capital+linkedin&t=all",
        "qwant",
    )
