# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_facebook_vanilla_1481832838():
    verify_serp_parsing(
        "https://web.archive.org/web/20161215201358id_/https://www.facebook.com/search/photos/?q=%23vanilla&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_virpi_soikkeli_1623257178():
    verify_serp_parsing(
        "https://web.archive.org/web/20210609164618id_/http://www.facebook.com/search/?q=virpi+soikkeli&o=2048&init=ffs",
        "facebook",
    )


def test_parse_query_facebook_deanna_sanchez_1629215596():
    verify_serp_parsing(
        "https://web.archive.org/web/20210817155316id_/https://www.facebook.com/search/web/direct_search.php?q=deanna+sanchez&dpr=1&ajaxpipe=1&ajaxpipe_token=AXivh35bR9s2xXXV&quickling%5Bversion%5D=3128950%3B0%3B&__user=100004323191030&__a=1&__dyn=5V4cjEzUGByC5A9UrEwlg94qbxqbAKGiyEyfirYw8ovyui9zob4q2i5UK3u2CEaUZ1ebkwy6UnGieKcVrDG4XzEa8iGt0gKum4UpKqqbAWCDxi5UWfz8gAxu1iyECQum2m4oqyU9omUmC-Wx2vgqx-Eth8gUKElCUmyE8XDh45EgAwzCwYyrK4rGUohES-9yaBy8CEO784afxK9yUvy8lUGaHCG2C&__af=j0&__req=jsonp_4&__be=0&__pc=PHASED%3ADEFAULT&__rev=3128950&__spin_r=3128950&__spin_b=trunk&__spin_t=1498867474&__adt=4",
        "facebook",
    )


def test_parse_query_facebook_mr_robot_1469187052():
    verify_serp_parsing(
        "https://web.archive.org/web/20160722113052id_/https://www.facebook.com/search/top/?q=mr%20robot",
        "facebook",
    )


def test_parse_query_facebook_https_peelarchivesblog_com_about_peel_1599241783():
    verify_serp_parsing(
        "https://web.archive.org/web/20200904174943id_/https://www.facebook.com/search/top?q=https%3A%2F%2Fpeelarchivesblog.com%2Fabout-peel%2F",
        "facebook",
    )


def test_parse_query_facebook_trumptrain_1461904486():
    verify_serp_parsing(
        "https://web.archive.org/web/20160429043446id_/https://www.facebook.com/search/top/?q=%23TrumpTrain&ref=top_filter&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_bernieorbust_1467812085():
    verify_serp_parsing(
        "https://web.archive.org/web/20160706133445id_/https://www.facebook.com/search/latest/?q=%23BernieOrBust&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_wisconsin_1463064570():
    verify_serp_parsing(
        "https://web.archive.org/web/20160512144930id_/https://www.facebook.com/search/top/?q=wisconsin&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_alda_lesbiennes_refugiees_1615284371():
    verify_serp_parsing(
        "https://web.archive.org/web/20210309100611id_/https://www.facebook.com/search/top/?q=alda%20-%20lesbiennes%20r%C3%A9fugi%C3%A9es&epa=SEARCH_BOX",
        "facebook",
    )


def test_parse_query_facebook_mens_health_survival_of_the_fittest_1619473718():
    verify_serp_parsing(
        "https://web.archive.org/web/20210426214838id_/http://www.facebook.com/search/?q=mens+health+survival+of+the+fittest&amp;init=quick",
        "facebook",
    )


def test_parse_query_facebook_www_9xcb_biz_webex_setup_was_unsuccessful_error_23_1404412853():
    verify_serp_parsing(
        "https://web.archive.org/web/20140703184053id_/http://www.facebook.com/search.php?q=www.9xcb.biz/?WebEx+Setup+Was+Unsuccessful+Error+23",
        "facebook",
    )


def test_parse_query_facebook_tag_someone_who_needs_this_1587554575():
    verify_serp_parsing(
        "https://web.archive.org/web/20200422112255id_/https://www.facebook.com/search/videos/?q=tag%20someone%20who%20needs%20this&epa=FILTERS&filters=eyJycF9jcmVhdGlvbl90aW1lIjoie1wibmFtZVwiOlwiY3JlYXRpb25fdGltZVwiLFwiYXJnc1wiOlwie1xcXCJzdGFydF95ZWFyXFxcIjpcXFwiMjAyMFxcXCIsXFxcInN0YXJ0X21vbnRoXFxcIjpcXFwiMjAyMC0wNFxcXCIsXFxcImVuZF95ZWFyXFxcIjpcXFwiMjAyMFxcXCIsXFxcImVuZF9tb250aFxcXCI6XFxcIjIwMjAtMDRcXFwiLFxcXCJzdGFydF9kYXlcXFwiOlxcXCIyMDIwLTA0LTIwXFxcIixcXFwiZW5kX2RheVxcXCI6XFxcIjIwMjAtMDQtMjZcXFwifVwifSJ9",
        "facebook",
    )


def test_parse_query_facebook_blog_post_334_bootload_1567494170():
    verify_serp_parsing(
        "https://web.archive.org/web/20190903070250id_/https://developers.facebook.com/search/?q=blog+post+334+bootload&notfound=0&search_filter_option=docs",
        "facebook",
    )


def test_parse_query_facebook_rosy_20gupta_1494524363():
    verify_serp_parsing(
        "https://web.archive.org/web/20170511173923id_/https://www.facebook.com/search/top/?q=rosy%2520gupta",
        "facebook",
    )


def test_parse_query_facebook_social_plugins_boutons_jaime_envoyer_partager_et_citations_js_exec_je31_1567485463():
    verify_serp_parsing(
        "https://web.archive.org/web/20190903043743id_/https://developers.facebook.com/search/?q=social+plugins+boutons+jaime+envoyer+partager+et+citations+js+exec+Je31&notfound=1&search_filter_option=docs",
        "facebook",
    )


def test_parse_query_facebook_greet_1623235952():
    verify_serp_parsing(
        "https://web.archive.org/web/20210609105232id_/http://www.facebook.com/search/?q=Greet&o=2048&init=ffs",
        "facebook",
    )


def test_parse_query_facebook_cruzcrew_1459272010():
    verify_serp_parsing(
        "https://web.archive.org/web/20160329172010id_/https://www.facebook.com/search/photos/?q=%23CruzCrew&ref=top_filter&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_ineligible_1466870871():
    verify_serp_parsing(
        "https://web.archive.org/web/20160625160751id_/https://www.facebook.com/search/people/?q=%23ineligible&ref=top_filter",
        "facebook",
    )


def test_parse_query_facebook_solcellespecialisten_1389488036():
    verify_serp_parsing(
        "https://web.archive.org/web/20140112005356id_/http://da-dk.facebook.com/search.php?q=Solcellespecialisten&_fb_noscript=1",
        "facebook",
    )


def test_parse_query_facebook_blog_post_319_je31_1567459151():
    verify_serp_parsing(
        "https://web.archive.org/web/20190902211911id_/https://developers.facebook.com/search/?q=blog+post+319+Je31&notfound=1&search_filter_option=news",
        "facebook",
    )
