# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_duckduckgo_3rd_party_twitch_chat_1642095474():
    verify_serp_parsing(
        "https://web.archive.org/web/20220113173754id_/https://duckduckgo.com/?q=3rd+party+twitch+chat&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_warren_hunt_1635806147():
    verify_serp_parsing(
        "https://web.archive.org/web/20211101223547id_/https://duckduckgo.com/?t=ffab&q=warren+hunt",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_150_degrees_to_radians_site_degreestoradians_net_1662073498():
    verify_serp_parsing(
        "https://web.archive.org/web/20220901230458id_/https://duckduckgo.com/?q=150%20degrees%20to%20radians+site:degreestoradians.net&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_we_acknowledge_the_traditional_custodians_of_the_land_on_which_our_office_stands_the_wurundjeri_peop_1654920640():
    verify_serp_parsing(
        "https://web.archive.org/web/20220611041040id_/https://duckduckgo.com/?q=We+acknowledge+the+Traditional+Custodians+of+the+land+on+which+our+office+stands%2C+The+Wurundjeri+people+of+the+Kulin+Nation%2C+and+pay+our+respects+to+Elders+past%2C+present+and+emerging.+site%3Awww.sandyps.vic.edu.au&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_quit_telnet_site_www_codegrepper_com_1665105234():
    verify_serp_parsing(
        "https://web.archive.org/web/20221007011354id_/https://duckduckgo.com/?q=quit%20telnet+site:www.codegrepper.com&t=ffab&atb=v325-1",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_breaking_news_on_sierra_leone_1663541702():
    verify_serp_parsing(
        "https://web.archive.org/web/20220918225502id_/https://duckduckgo.com/?q=breaking%20news%20on%20sierra%20leone&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_empure_site_empure_in_1664600213():
    verify_serp_parsing(
        "https://web.archive.org/web/20221001045653id_/https://duckduckgo.com/?q=empure+site:empure.in&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elton_john_site_www_esquire_com_1657307467():
    verify_serp_parsing(
        "https://web.archive.org/web/20220708191107id_/https://duckduckgo.com/?q=elton+john+site%3Awww.esquire.com&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_waterford_house_erfstadt_court_wokingham_berkshire_rg40_2yf_google_maps_1660892879():
    verify_serp_parsing(
        "https://web.archive.org/web/20220819070759id_/https://duckduckgo.com/?q=Waterford+House%2C+Erfstadt+Court+Wokingham%2C+Berkshire%2C+RG40+2YF+google+maps",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_2_5_muiles_to_km_1648676868():
    verify_serp_parsing(
        "https://web.archive.org/web/20220330214748id_/https://duckduckgo.com/?t=ffab&q=2.5+muiles+to+km",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_32168_weather_radar_1667504070():
    verify_serp_parsing(
        "https://web.archive.org/web/20221103193430id_/https://duckduckgo.com/?q=32168%20weather%20radar&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_buck_showalter_seinfeld_1654420295():
    verify_serp_parsing(
        "https://web.archive.org/web/20220605091135id_/https://duckduckgo.com/?q=buck+showalter+seinfeld&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elite_dangerous_covas_site_www_pcgamer_com_1653704722():
    verify_serp_parsing(
        "https://web.archive.org/web/20220528022522id_/https://duckduckgo.com/?q=elite+dangerous+covas+site%3Awww.pcgamer.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_waldo_s_chicken_site_waldoschicken_com_1654372116():
    verify_serp_parsing(
        "https://web.archive.org/web/20220604194836id_/https://duckduckgo.com/?q=waldo%27s+chicken+site%3Awaldoschicken.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sims_castaway_trailer_1647012563():
    verify_serp_parsing(
        "https://web.archive.org/web/20220311152923id_/https://duckduckgo.com/?q=sims+castaway+trailer&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_emoji_pedia_site_www_youtube_com_1590838578():
    verify_serp_parsing(
        "https://web.archive.org/web/20200530113618id_/https://duckduckgo.com/?q=emoji%20pedia+site:www.youtube.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheer_skirt_beach_thing_site_www_lyst_com_1653921398():
    verify_serp_parsing(
        "https://web.archive.org/web/20220530143638id_/https://duckduckgo.com/?q=sheer+skirt+beach+thing+site%3Awww.lyst.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_broken_reality_steam_site_www_huntmar_com_1597289631():
    verify_serp_parsing(
        "https://web.archive.org/web/20200813033351id_/https://duckduckgo.com/?q=broken+reality+steam+site%3Awww.huntmar.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheets_site_www_kohls_com_1642928572():
    verify_serp_parsing(
        "https://web.archive.org/web/20220123090252id_/https://duckduckgo.com/?q=sheets+site%3Awww.kohls.com",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_145_lbs_to_kg_1664351690():
    verify_serp_parsing(
        "https://web.archive.org/web/20220928075450id_/https://duckduckgo.com/?q=145%20lbs%20to%20kg&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_gimp_use_align_tool_site_thegimptutorials_com_1653712700():
    verify_serp_parsing(
        "https://web.archive.org/web/20220528043820id_/https://duckduckgo.com/?q=gimp+use+align+tool+site%3Athegimptutorials.com&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ubuntu_mesa_intel_r_hd_graphics_620_kbl_gt2_site_forum_unity_com_1658976095():
    verify_serp_parsing(
        "https://web.archive.org/web/20220728024135id_/https://duckduckgo.com/?q=ubuntu+Mesa+Intel%28R%29+HD+Graphics+620+%28KBL+GT2%29+site%3Aforum.unity.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_2022_07_12_23_00_site_www_time_time_net_1657640396():
    verify_serp_parsing(
        "https://web.archive.org/web/20220712153956id_/https://duckduckgo.com/?q=2022-07-12+23%3A00+site%3Awww.time-time.net&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_branch_conventions_git_site_social_msdn_microsoft_com_1664392383():
    verify_serp_parsing(
        "https://web.archive.org/web/20220928191303id_/https://duckduckgo.com/?q=branch%20conventions%20git+site:social.msdn.microsoft.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_enneagram_test_site_www_crystalknows_com_1638683347():
    verify_serp_parsing(
        "https://web.archive.org/web/20211205054907id_/https://duckduckgo.com/?q=enneagram+test+site%3Awww.crystalknows.com",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_universal_logs_checker_1_1_0_site_cracking_org_1656559962():
    verify_serp_parsing(
        "https://web.archive.org/web/20220630033242id_/https://duckduckgo.com/?q=Universal+Logs+Checker+1.1.0+site%3Acracking.org&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_25_c_to_f_site_www_metric_conversions_org_1655636638():
    verify_serp_parsing(
        "https://web.archive.org/web/20220619110358id_/https://duckduckgo.com/?q=25+C+to+F+site%3Awww.metric-conversions.org&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_u_team_1636548723():
    verify_serp_parsing(
        "https://web.archive.org/web/20211110125203id_/https://duckduckgo.com/?q=u+team",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_sheydim_site_www_sefaria_org_1664233097():
    verify_serp_parsing(
        "https://web.archive.org/web/20220926225817id_/https://duckduckgo.com/?q=Sheydim+site:www.sefaria.org&t=ffcm",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_build_chest_freezer_site_www_quora_com_1654893310():
    verify_serp_parsing(
        "https://web.archive.org/web/20220610203510id_/https://duckduckgo.com/?q=build+chest+freezer+site%3Awww.quora.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_jeanne_d_arc_site_id_wikipedia_org_1655183773():
    verify_serp_parsing(
        "https://web.archive.org/web/20220614051613id_/https://duckduckgo.com/?q=Jeanne+d%27Arc+site%3Aid.wikipedia.org&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_update_admx_files_on_domain_controller_1660061931():
    verify_serp_parsing(
        "https://web.archive.org/web/20220809161851id_/https://duckduckgo.com/?q=update%20admx%20files%20on%20domain%20controller&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_newest_call_of_duty_game_1653477001():
    verify_serp_parsing(
        "https://web.archive.org/web/20220525111001id_/https://duckduckgo.com/?q=newest+call+of+duty+game&t=ffab&atb=v325-4",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_40_mile_creek_trail_site_www_arizonahighways_com_1657173375():
    verify_serp_parsing(
        "https://web.archive.org/web/20220707055615id_/https://duckduckgo.com/?q=40+mile+creek+trail+site%3Awww.arizonahighways.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_united_reformed_churches_in_north_america_1446324275():
    verify_serp_parsing(
        "https://web.archive.org/web/20151031204435id_/https://duckduckgo.com/?q=united+reformed+churches+in+north+america",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_burnout_paradise_online_multiplayer_with_all_dlc_site_www_counton_org_1655566858():
    verify_serp_parsing(
        "https://web.archive.org/web/20220618154058id_/https://duckduckgo.com/?q=burnout+paradise+online+multiplayer+with+all+dlc+site%3Awww.counton.org",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_what_happened_to_greta_thornburg_1667535932():
    verify_serp_parsing(
        "https://web.archive.org/web/20221104042532id_/https://duckduckgo.com/?q=what%20happened%20to%20greta%20thornburg&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_erik_erikson_s_theory_site_positivepsychology_com_1654620203():
    verify_serp_parsing(
        "https://web.archive.org/web/20220607164323id_/https://duckduckgo.com/?q=erik+erikson%27s+theory+site%3Apositivepsychology.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_llanelly_carmarthenshire_wales_1655261859():
    verify_serp_parsing(
        "https://web.archive.org/web/20220615025739id_/https://duckduckgo.com/?q=llanelly+carmarthenshire+wales&t=ffab&atb=v325-7",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_c_pretty_print_json_1662310061():
    verify_serp_parsing(
        "https://web.archive.org/web/20220904164741id_/https://duckduckgo.com/?q=c%23%20pretty%20print%20json&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_webassembly_browser_support_list_1653198525():
    verify_serp_parsing(
        "https://web.archive.org/web/20220522054845id_/https://duckduckgo.com/?q=webassembly+browser+support+list&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_bulk_copper_pennies_for_sale_1646606334():
    verify_serp_parsing(
        "https://web.archive.org/web/20220306223854id_/https://duckduckgo.com/?q=bulk+copper+pennies+for+sale&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ubuntu_netplan_package_site_www_ubuntuupdates_org_1665115336():
    verify_serp_parsing(
        "https://web.archive.org/web/20221007040216id_/https://duckduckgo.com/?q=ubuntu%20netplan%20package+site:www.ubuntuupdates.org&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_ukraine_site_www_cfr_org_1646796603():
    verify_serp_parsing(
        "https://web.archive.org/web/20220309033003id_/https://duckduckgo.com/?q=Ukraine+site%3Awww.cfr.org&t=opera",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_simplify_subtraction_of_fractals_site_www_thecalculator_co_1637459222():
    verify_serp_parsing(
        "https://web.archive.org/web/20211121014702id_/https://duckduckgo.com/?q=simplify+subtraction+of+fractals+site%3Awww.thecalculator.co&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_equation_of_dissociation_of_sulfuric_acid_site_www_sciencedirect_com_1649296927():
    verify_serp_parsing(
        "https://web.archive.org/web/20220407020207id_/https://duckduckgo.com/?q=equation+of+dissociation+of+sulfuric+acid+site%3Awww.sciencedirect.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_elite_dangerous_site_www_thegamer_com_1658908937():
    verify_serp_parsing(
        "https://web.archive.org/web/20220727080217id_/https://duckduckgo.com/?q=Elite%3A+Dangerous+site%3Awww.thegamer.com&t=ffab",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_website_sitemap_finder_site_seositecheckup_com_1614287233():
    verify_serp_parsing(
        "https://web.archive.org/web/20210225210713id_/https://duckduckgo.com/?q=website+sitemap+finder+site%3Aseositecheckup.com&t=brave",
        "duckduckgo",
    )


def test_parse_query_duckduckgo_encountered_conflicts_when_cherry_picking_commit_1618189582():
    verify_serp_parsing(
        "https://web.archive.org/web/20210412010622id_/https://duckduckgo.com/?q=encountered+conflicts+when+cherry+picking+commit&t=ffab",
        "duckduckgo",
    )
